@@ -24,8 +24,7 @@ def build_app_list(app_list: dict[str, str]) -> BrowseMedia:
 
 
 def item_payload(item: dict[str, Any]) -> BrowseMedia:
-    """
-    Create response payload for a single media item.
+    """Create response payload for a single media item.
 
     Used by async_browse_media.
     """
