@@ -68,7 +68,7 @@ class AzureEventHubClientSAS(AzureEventHubClient):
                 f"{self.event_hub_namespace}.servicebus.windows.net"
             ),
             eventhub_name=self.event_hub_instance_name,
-            credential=EventHubSharedKeyCredential(  # type: ignore[arg-type]
+            credential=EventHubSharedKeyCredential(
                 policy=self.event_hub_sas_policy, key=self.event_hub_sas_key
             ),
             **ADDITIONAL_ARGS,
