@@ -8,7 +8,7 @@ from pyblockchain import get_balance, validate_address
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA, SensorEntity
-from homeassistant.const import ATTR_ATTRIBUTION, CONF_NAME
+from homeassistant.const import CONF_NAME
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -16,14 +16,10 @@ from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTRIBUTION = "Data provided by blockchain.com"
-
 CONF_ADDRESSES = "addresses"
 
 DEFAULT_NAME = "Bitcoin Balance"
 
-ICON = "mdi:currency-btc"
-
 SCAN_INTERVAL = timedelta(minutes=5)
 
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
@@ -42,8 +38,8 @@ def setup_platform(
 ) -> None:
     """Set up the Blockchain.com sensors."""
 
-    addresses = config[CONF_ADDRESSES]
-    name = config[CONF_NAME]
+    addresses: list[str] = config[CONF_ADDRESSES]
+    name: str = config[CONF_NAME]
 
     for address in addresses:
         if not validate_address(address):
@@ -56,11 +52,11 @@ def setup_platform(
 class BlockchainSensor(SensorEntity):
     """Representation of a Blockchain.com sensor."""
 
-    _attr_extra_state_attributes = {ATTR_ATTRIBUTION: ATTRIBUTION}
-    _attr_icon = ICON
+    _attr_attribution = "Data provided by blockchain.com"
+    _attr_icon = "mdi:currency-btc"
     _attr_native_unit_of_measurement = "BTC"
 
-    def __init__(self, name, addresses):
+    def __init__(self, name: str, addresses: list[str]) -> None:
         """Initialize the sensor."""
         self._attr_name = name
         self.addresses = addresses
