@@ -20,12 +20,12 @@ from homeassistant.const import (
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.reload import setup_reload_service
+from homeassistant.helpers.reload import async_setup_reload_service
 from homeassistant.helpers.template import Template
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
-from . import call_shell_with_timeout, check_output_or_log
 from .const import CONF_COMMAND_TIMEOUT, DEFAULT_TIMEOUT, DOMAIN, PLATFORMS
+from .utils import call_shell_with_timeout, check_output_or_log
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -47,15 +47,15 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 )
 
 
-def setup_platform(
+async def async_setup_platform(
     hass: HomeAssistant,
     config: ConfigType,
-    add_entities: AddEntitiesCallback,
+    async_add_entities: AddEntitiesCallback,
     discovery_info: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up cover controlled by shell commands."""
 
-    setup_reload_service(hass, DOMAIN, PLATFORMS)
+    await async_setup_reload_service(hass, DOMAIN, PLATFORMS)
 
     devices: dict[str, Any] = config.get(CONF_COVERS, {})
     covers = []
@@ -82,7 +82,7 @@ def setup_platform(
         _LOGGER.error("No covers added")
         return
 
-    add_entities(covers)
+    async_add_entities(covers)
 
 
 class CommandCover(CoverEntity):
@@ -148,13 +148,17 @@ class CommandCover(CoverEntity):
         if TYPE_CHECKING:
             return None
 
-    def update(self) -> None:
+    async def async_update(self) -> None:
         """Update device state."""
         if self._command_state:
-            payload = str(self._query_state())
+            payload = str(await self.hass.async_add_executor_job(self._query_state))
             if self._value_template:
-                payload = self._value_template.render_with_possible_json_value(payload)
-            self._state = int(payload)
+                payload = self._value_template.async_render_with_possible_json_value(
+                    payload, None
+                )
+            self._state = None
+            if payload:
+                self._state = int(payload)
 
     def open_cover(self, **kwargs: Any) -> None:
         """Open the cover."""
