@@ -3,6 +3,7 @@ from __future__ import annotations
 
 import logging
 import subprocess
+from typing import Any
 
 import voluptuous as vol
 
@@ -46,7 +47,7 @@ class CommandLineNotificationService(BaseNotificationService):
         self.command = command
         self._timeout = timeout
 
-    def send_message(self, message="", **kwargs) -> None:
+    def send_message(self, message: str = "", **kwargs: Any) -> None:
         """Send a message to a command line."""
         with subprocess.Popen(
             self.command,
