@@ -5,10 +5,11 @@ import math
 
 from aioesphomeapi import NumberInfo, NumberMode as EsphomeNumberMode, NumberState
 
-from homeassistant.components.number import NumberEntity, NumberMode
+from homeassistant.components.number import NumberDeviceClass, NumberEntity, NumberMode
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.util.enum import try_parse_enum
 
 from . import (
     EsphomeEntity,
@@ -47,6 +48,11 @@ NUMBER_MODES: EsphomeEnumMapper[EsphomeNumberMode, NumberMode] = EsphomeEnumMapp
 class EsphomeNumber(EsphomeEntity[NumberInfo, NumberState], NumberEntity):
     """A number implementation for esphome."""
 
+    @property
+    def device_class(self) -> NumberDeviceClass | None:
+        """Return the class of this entity."""
+        return try_parse_enum(NumberDeviceClass, self._static_info.device_class)
+
     @property
     def native_min_value(self) -> float:
         """Return the minimum value."""
@@ -74,7 +80,7 @@ class EsphomeNumber(EsphomeEntity[NumberInfo, NumberState], NumberEntity):
             return NUMBER_MODES.from_esphome(self._static_info.mode)
         return NumberMode.AUTO
 
-    @property  # type: ignore[misc]
+    @property
     @esphome_state_property
     def native_value(self) -> float | None:
         """Return the state of the entity."""
