@@ -15,14 +15,21 @@ from homeassistant.const import EntityCategory
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from .common import AvmWrapper, ConnectionInfo, FritzBoxBaseEntity
+from .common import (
+    AvmWrapper,
+    ConnectionInfo,
+    FritzBoxBaseCoordinatorEntity,
+    FritzEntityDescription,
+)
 from .const import DOMAIN
 
 _LOGGER = logging.getLogger(__name__)
 
 
 @dataclass
-class FritzBinarySensorEntityDescription(BinarySensorEntityDescription):
+class FritzBinarySensorEntityDescription(
+    BinarySensorEntityDescription, FritzEntityDescription
+):
     """Describes Fritz sensor entity."""
 
     is_suitable: Callable[[ConnectionInfo], bool] = lambda info: info.wan_enabled
@@ -31,24 +38,17 @@ class FritzBinarySensorEntityDescription(BinarySensorEntityDescription):
 SENSOR_TYPES: tuple[FritzBinarySensorEntityDescription, ...] = (
     FritzBinarySensorEntityDescription(
         key="is_connected",
-        name="Connection",
+        translation_key="is_connected",
         device_class=BinarySensorDeviceClass.CONNECTIVITY,
         entity_category=EntityCategory.DIAGNOSTIC,
+        value_fn=lambda status, _: bool(status.is_connected),
     ),
     FritzBinarySensorEntityDescription(
         key="is_linked",
-        name="Link",
+        translation_key="is_linked",
         device_class=BinarySensorDeviceClass.PLUG,
         entity_category=EntityCategory.DIAGNOSTIC,
-    ),
-    FritzBinarySensorEntityDescription(
-        # Deprecated, scheduled to be removed in 2022.7 (#70096)
-        entity_registry_enabled_default=False,
-        key="firmware_update",
-        name="Firmware Update",
-        device_class=BinarySensorDeviceClass.UPDATE,
-        entity_category=EntityCategory.DIAGNOSTIC,
-        is_suitable=lambda info: True,
+        value_fn=lambda status, _: bool(status.is_linked),
     ),
 )
 
@@ -71,32 +71,16 @@ async def async_setup_entry(
     async_add_entities(entities, True)
 
 
-class FritzBoxBinarySensor(FritzBoxBaseEntity, BinarySensorEntity):
+class FritzBoxBinarySensor(FritzBoxBaseCoordinatorEntity, BinarySensorEntity):
     """Define FRITZ!Box connectivity class."""
 
-    def __init__(
-        self,
-        avm_wrapper: AvmWrapper,
-        device_friendly_name: str,
-        description: BinarySensorEntityDescription,
-    ) -> None:
-        """Init FRITZ!Box connectivity class."""
-        self.entity_description = description
-        self._attr_name = f"{device_friendly_name} {description.name}"
-        self._attr_unique_id = f"{avm_wrapper.unique_id}-{description.key}"
-        super().__init__(avm_wrapper, device_friendly_name)
+    entity_description: FritzBinarySensorEntityDescription
 
-    def update(self) -> None:
-        """Update data."""
-        _LOGGER.debug("Updating FRITZ!Box binary sensors")
-
-        if self.entity_description.key == "firmware_update":
-            self._attr_is_on = self._avm_wrapper.update_available
-            self._attr_extra_state_attributes = {
-                "installed_version": self._avm_wrapper.current_firmware,
-                "latest_available_version": self._avm_wrapper.latest_firmware,
-            }
-        if self.entity_description.key == "is_connected":
-            self._attr_is_on = bool(self._avm_wrapper.fritz_status.is_connected)
-        elif self.entity_description.key == "is_linked":
-            self._attr_is_on = bool(self._avm_wrapper.fritz_status.is_linked)
+    @property
+    def is_on(self) -> bool | None:
+        """Return true if the binary sensor is on."""
+        if isinstance(
+            state := self.coordinator.data.get(self.entity_description.key), bool
+        ):
+            return state
+        return None
