@@ -74,17 +74,6 @@ def suitable_temperature(device: FritzhomeDevice) -> bool:
     return device.has_temperature_sensor and not device.has_thermostat
 
 
-def value_electric_current(device: FritzhomeDevice) -> float:
-    """Return native value for electric current sensor."""
-    if (
-        isinstance(device.power, int)
-        and isinstance(device.voltage, int)
-        and device.voltage > 0
-    ):
-        return round(device.power / device.voltage, 3)
-    return 0.0
-
-
 def value_nextchange_preset(device: FritzhomeDevice) -> str:
     """Return native value for next scheduled preset sensor."""
     if device.nextchange_temperature == device.eco_temperature:
@@ -102,7 +91,7 @@ def value_scheduled_preset(device: FritzhomeDevice) -> str:
 SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     FritzSensorEntityDescription(
         key="temperature",
-        name="Temperature",
+        translation_key="temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
@@ -112,7 +101,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="humidity",
-        name="Humidity",
+        translation_key="humidity",
         native_unit_of_measurement=PERCENTAGE,
         device_class=SensorDeviceClass.HUMIDITY,
         state_class=SensorStateClass.MEASUREMENT,
@@ -121,7 +110,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="battery",
-        name="Battery",
+        translation_key="battery",
         native_unit_of_measurement=PERCENTAGE,
         device_class=SensorDeviceClass.BATTERY,
         entity_category=EntityCategory.DIAGNOSTIC,
@@ -130,7 +119,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="power_consumption",
-        name="Power Consumption",
+        translation_key="power_consumption",
         native_unit_of_measurement=UnitOfPower.WATT,
         device_class=SensorDeviceClass.POWER,
         state_class=SensorStateClass.MEASUREMENT,
@@ -139,7 +128,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="voltage",
-        name="Voltage",
+        translation_key="voltage",
         native_unit_of_measurement=UnitOfElectricPotential.VOLT,
         device_class=SensorDeviceClass.VOLTAGE,
         state_class=SensorStateClass.MEASUREMENT,
@@ -148,16 +137,16 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="electric_current",
-        name="Electric Current",
+        translation_key="electric_current",
         native_unit_of_measurement=UnitOfElectricCurrent.AMPERE,
         device_class=SensorDeviceClass.CURRENT,
         state_class=SensorStateClass.MEASUREMENT,
         suitable=lambda device: device.has_powermeter,  # type: ignore[no-any-return]
-        native_value=value_electric_current,
+        native_value=lambda device: round((device.current or 0.0) / 1000, 3),
     ),
     FritzSensorEntityDescription(
         key="total_energy",
-        name="Total Energy",
+        translation_key="total_energy",
         native_unit_of_measurement=UnitOfEnergy.KILO_WATT_HOUR,
         device_class=SensorDeviceClass.ENERGY,
         state_class=SensorStateClass.TOTAL_INCREASING,
@@ -167,7 +156,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     # Thermostat Sensors
     FritzSensorEntityDescription(
         key="comfort_temperature",
-        name="Comfort Temperature",
+        translation_key="comfort_temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         suitable=suitable_comfort_temperature,
@@ -175,7 +164,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="eco_temperature",
-        name="Eco Temperature",
+        translation_key="eco_temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         suitable=suitable_eco_temperature,
@@ -183,7 +172,7 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="nextchange_temperature",
-        name="Next Scheduled Temperature",
+        translation_key="nextchange_temperature",
         native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         suitable=suitable_nextchange_temperature,
@@ -191,20 +180,20 @@ SENSOR_TYPES: Final[tuple[FritzSensorEntityDescription, ...]] = (
     ),
     FritzSensorEntityDescription(
         key="nextchange_time",
-        name="Next Scheduled Change Time",
+        translation_key="nextchange_time",
         device_class=SensorDeviceClass.TIMESTAMP,
         suitable=suitable_nextchange_time,
         native_value=lambda device: utc_from_timestamp(device.nextchange_endperiod),
     ),
     FritzSensorEntityDescription(
         key="nextchange_preset",
-        name="Next Scheduled Preset",
+        translation_key="nextchange_preset",
         suitable=suitable_nextchange_temperature,
         native_value=value_nextchange_preset,
     ),
     FritzSensorEntityDescription(
         key="scheduled_preset",
-        name="Current Scheduled Preset",
+        translation_key="scheduled_preset",
         suitable=suitable_nextchange_temperature,
         native_value=value_scheduled_preset,
     ),
