@@ -1,4 +1,6 @@
 """Constants for the HERE Travel Time integration."""
+from typing import Final
+
 DOMAIN = "here_travel_time"
 DEFAULT_SCAN_INTERVAL = 300
 
@@ -11,7 +13,6 @@ CONF_ORIGIN = "origin"
 CONF_ORIGIN_LATITUDE = "origin_latitude"
 CONF_ORIGIN_LONGITUDE = "origin_longitude"
 CONF_ORIGIN_ENTITY_ID = "origin_entity_id"
-CONF_TRAFFIC_MODE = "traffic_mode"
 CONF_ROUTE_MODE = "route_mode"
 CONF_ARRIVAL = "arrival"
 CONF_DEPARTURE = "departure"
@@ -24,23 +25,17 @@ TRAVEL_MODE_BICYCLE = "bicycle"
 TRAVEL_MODE_CAR = "car"
 TRAVEL_MODE_PEDESTRIAN = "pedestrian"
 TRAVEL_MODE_PUBLIC = "publicTransport"
-TRAVEL_MODE_PUBLIC_TIME_TABLE = "publicTransportTimeTable"
 TRAVEL_MODE_TRUCK = "truck"
 TRAVEL_MODES = [
     TRAVEL_MODE_BICYCLE,
     TRAVEL_MODE_CAR,
     TRAVEL_MODE_PEDESTRIAN,
     TRAVEL_MODE_PUBLIC,
-    TRAVEL_MODE_PUBLIC_TIME_TABLE,
     TRAVEL_MODE_TRUCK,
 ]
 
 TRAVEL_MODES_VEHICLE = [TRAVEL_MODE_CAR, TRAVEL_MODE_TRUCK]
 
-TRAFFIC_MODE_ENABLED = "traffic_enabled"
-TRAFFIC_MODE_DISABLED = "traffic_disabled"
-TRAFFIC_MODES = [TRAFFIC_MODE_ENABLED, TRAFFIC_MODE_DISABLED]
-
 ROUTE_MODE_FASTEST = "fastest"
 ROUTE_MODE_SHORTEST = "shortest"
 ROUTE_MODES = [ROUTE_MODE_FASTEST, ROUTE_MODE_SHORTEST]
@@ -55,24 +50,14 @@ ICONS = {
     TRAVEL_MODE_BICYCLE: ICON_BICYCLE,
     TRAVEL_MODE_PEDESTRIAN: ICON_PEDESTRIAN,
     TRAVEL_MODE_PUBLIC: ICON_PUBLIC,
-    TRAVEL_MODE_PUBLIC_TIME_TABLE: ICON_PUBLIC,
     TRAVEL_MODE_TRUCK: ICON_TRUCK,
 }
 
-IMPERIAL_UNITS = "imperial"
-METRIC_UNITS = "metric"
-UNITS = [METRIC_UNITS, IMPERIAL_UNITS]
+ATTR_DURATION: Final = "duration"
+ATTR_DISTANCE: Final = "distance"
+ATTR_ORIGIN: Final = "origin"
+ATTR_DESTINATION: Final = "destination"
 
-ATTR_DURATION = "duration"
-ATTR_DISTANCE = "distance"
-ATTR_ORIGIN = "origin"
-ATTR_DESTINATION = "destination"
-
-ATTR_UNIT_SYSTEM = "unit_system"
-ATTR_TRAFFIC_MODE = CONF_TRAFFIC_MODE
-
-ATTR_DURATION_IN_TRAFFIC = "duration_in_traffic"
-ATTR_ORIGIN_NAME = "origin_name"
-ATTR_DESTINATION_NAME = "destination_name"
-
-NO_ROUTE_ERROR_MESSAGE = "HERE could not find a route based on the input"
+ATTR_DURATION_IN_TRAFFIC: Final = "duration_in_traffic"
+ATTR_ORIGIN_NAME: Final = "origin_name"
+ATTR_DESTINATION_NAME: Final = "destination_name"
