@@ -41,7 +41,7 @@ class Iperf3Sensor(RestoreEntity, SensorEntity):
     _attr_attribution = "Data retrieved using Iperf3"
     _attr_should_poll = False
 
-    def __init__(self, iperf3_data, description: SensorEntityDescription):
+    def __init__(self, iperf3_data, description: SensorEntityDescription) -> None:
         """Initialize the sensor."""
         self.entity_description = description
         self._iperf3_data = iperf3_data
