@@ -2,7 +2,9 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import logging
+from pathlib import Path
 from typing import Final
 
 import voluptuous as vol
@@ -67,6 +69,7 @@ from .const import (
     KNX_ADDRESS,
     SUPPORTED_PLATFORMS,
 )
+from .device import KNXInterfaceDevice
 from .expose import KNXExposeSensor, KNXExposeTime, create_knx_exposure
 from .schema import (
     BinarySensorSchema,
@@ -224,7 +227,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Load a config entry."""
-    # `config` is None when reloading the integration or no `knx` key in configuration.yaml
+    # `config` is None when reloading the integration
+    # or no `knx` key in configuration.yaml
     if (config := hass.data.get(DATA_KNX_CONFIG)) is None:
         _conf = await async_integration_yaml_config(hass, DOMAIN)
         if not _conf or DOMAIN not in _conf:
@@ -251,13 +255,14 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
             knx_module.exposures.append(
                 create_knx_exposure(hass, knx_module.xknx, expose_config)
             )
-
+    # always forward sensor for system entities (telegram counter, etc.)
+    await hass.config_entries.async_forward_entry_setup(entry, Platform.SENSOR)
     await hass.config_entries.async_forward_entry_setups(
         entry,
         [
             platform
             for platform in SUPPORTED_PLATFORMS
-            if platform in config and platform is not Platform.NOTIFY
+            if platform in config and platform not in (Platform.SENSOR, Platform.NOTIFY)
         ],
     )
 
@@ -334,6 +339,21 @@ async def async_update_entry(hass: HomeAssistant, entry: ConfigEntry) -> None:
     await hass.config_entries.async_reload(entry.entry_id)
 
 
+async def async_remove_entry(hass: HomeAssistant, entry: ConfigEntry) -> None:
+    """Remove a config entry."""
+
+    def remove_keyring_files(file_path: Path) -> None:
+        """Remove keyring files."""
+        with contextlib.suppress(FileNotFoundError):
+            file_path.unlink()
+        with contextlib.suppress(FileNotFoundError, OSError):
+            file_path.parent.rmdir()
+
+    if (_knxkeys_file := entry.data.get(CONF_KNX_KNXKEY_FILENAME)) is not None:
+        file_path = Path(hass.config.path(STORAGE_DIR)) / _knxkeys_file
+        await hass.async_add_executor_job(remove_keyring_files, file_path)
+
+
 class KNXModule:
     """Representation of KNX Object."""
 
@@ -348,10 +368,17 @@ class KNXModule:
         self.service_exposures: dict[str, KNXExposeSensor | KNXExposeTime] = {}
         self.entry = entry
 
-        self.init_xknx()
+        self.xknx = XKNX(
+            connection_config=self.connection_config(),
+            rate_limit=self.entry.data[CONF_KNX_RATE_LIMIT],
+            state_updater=self.entry.data[CONF_KNX_STATE_UPDATER],
+        )
         self.xknx.connection_manager.register_connection_state_changed_cb(
             self.connection_state_changed_cb
         )
+        self.interface_device = KNXInterfaceDevice(
+            hass=hass, entry=entry, xknx=self.xknx
+        )
 
         self._address_filter_transcoder: dict[AddressFilter, type[DPTBase]] = {}
         self._group_address_transcoder: dict[DeviceGroupAddress, type[DPTBase]] = {}
@@ -364,14 +391,6 @@ class KNXModule:
         )
         self.entry.async_on_unload(self.entry.add_update_listener(async_update_entry))
 
-    def init_xknx(self) -> None:
-        """Initialize XKNX object."""
-        self.xknx = XKNX(
-            connection_config=self.connection_config(),
-            rate_limit=self.entry.data[CONF_KNX_RATE_LIMIT],
-            state_updater=self.entry.data[CONF_KNX_STATE_UPDATER],
-        )
-
     async def start(self) -> None:
         """Start XKNX object. Connect to tunneling or Routing device."""
         await self.xknx.start()
@@ -383,6 +402,14 @@ class KNXModule:
     def connection_config(self) -> ConnectionConfig:
         """Return the connection_config."""
         _conn_type: str = self.entry.data[CONF_KNX_CONNECTION_TYPE]
+        _knxkeys_file: str | None = (
+            self.hass.config.path(
+                STORAGE_DIR,
+                self.entry.data[CONF_KNX_KNXKEY_FILENAME],
+            )
+            if self.entry.data.get(CONF_KNX_KNXKEY_FILENAME) is not None
+            else None
+        )
         if _conn_type == CONF_KNX_ROUTING:
             return ConnectionConfig(
                 connection_type=ConnectionType.ROUTING,
@@ -391,6 +418,10 @@ class KNXModule:
                 multicast_port=self.entry.data[CONF_KNX_MCAST_PORT],
                 local_ip=self.entry.data.get(CONF_KNX_LOCAL_IP),
                 auto_reconnect=True,
+                secure_config=SecureConfig(
+                    knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
+                    knxkeys_file_path=_knxkeys_file,
+                ),
                 threaded=True,
             )
         if _conn_type == CONF_KNX_TUNNELING:
@@ -401,6 +432,10 @@ class KNXModule:
                 local_ip=self.entry.data.get(CONF_KNX_LOCAL_IP),
                 route_back=self.entry.data.get(CONF_KNX_ROUTE_BACK, False),
                 auto_reconnect=True,
+                secure_config=SecureConfig(
+                    knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
+                    knxkeys_file_path=_knxkeys_file,
+                ),
                 threaded=True,
             )
         if _conn_type == CONF_KNX_TUNNELING_TCP:
@@ -409,16 +444,12 @@ class KNXModule:
                 gateway_ip=self.entry.data[CONF_HOST],
                 gateway_port=self.entry.data[CONF_PORT],
                 auto_reconnect=True,
+                secure_config=SecureConfig(
+                    knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
+                    knxkeys_file_path=_knxkeys_file,
+                ),
                 threaded=True,
             )
-        knxkeys_file: str | None = (
-            self.hass.config.path(
-                STORAGE_DIR,
-                self.entry.data[CONF_KNX_KNXKEY_FILENAME],
-            )
-            if self.entry.data.get(CONF_KNX_KNXKEY_FILENAME) is not None
-            else None
-        )
         if _conn_type == CONF_KNX_TUNNELING_TCP_SECURE:
             return ConnectionConfig(
                 connection_type=ConnectionType.TUNNELING_TCP_SECURE,
@@ -431,7 +462,7 @@ class KNXModule:
                         CONF_KNX_SECURE_DEVICE_AUTHENTICATION
                     ),
                     knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
-                    knxkeys_file_path=knxkeys_file,
+                    knxkeys_file_path=_knxkeys_file,
                 ),
                 auto_reconnect=True,
                 threaded=True,
@@ -449,13 +480,17 @@ class KNXModule:
                         CONF_KNX_ROUTING_SYNC_LATENCY_TOLERANCE
                     ),
                     knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
-                    knxkeys_file_path=knxkeys_file,
+                    knxkeys_file_path=_knxkeys_file,
                 ),
                 auto_reconnect=True,
                 threaded=True,
             )
         return ConnectionConfig(
             auto_reconnect=True,
+            secure_config=SecureConfig(
+                knxkeys_password=self.entry.data.get(CONF_KNX_KNXKEY_PASSWORD),
+                knxkeys_file_path=_knxkeys_file,
+            ),
             threaded=True,
         )
 
@@ -526,7 +561,10 @@ class KNXModule:
                 transcoder := DPTBase.parse_transcoder(dpt)
             ):
                 self._address_filter_transcoder.update(
-                    {_filter: transcoder for _filter in _filters}  # type: ignore[type-abstract]
+                    {
+                        _filter: transcoder  # type: ignore[type-abstract]
+                        for _filter in _filters
+                    }
                 )
 
         return self.xknx.telegram_queue.register_telegram_received_cb(
@@ -558,7 +596,10 @@ class KNXModule:
             transcoder := DPTBase.parse_transcoder(dpt)
         ):
             self._group_address_transcoder.update(
-                {_address: transcoder for _address in group_addresses}  # type: ignore[type-abstract]
+                {
+                    _address: transcoder  # type: ignore[type-abstract]
+                    for _address in group_addresses
+                }
             )
         for group_address in group_addresses:
             if group_address in self._knx_event_callback.group_addresses:
@@ -580,8 +621,8 @@ class KNXModule:
                 raise HomeAssistantError(
                     f"Could not find exposure for '{group_address}' to remove."
                 ) from err
-            else:
-                removed_exposure.shutdown()
+
+            removed_exposure.shutdown()
             return
 
         if group_address in self.service_exposures:
