@@ -1,19 +1,17 @@
 """The Landis+Gyr Heat Meter integration."""
 from __future__ import annotations
 
-from datetime import timedelta
 import logging
 
 import ultraheat_api
-from ultraheat_api.response import HeatMeterResponse
 
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_DEVICE, Platform
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity_registry import async_migrate_entries
-from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 
 from .const import DOMAIN
+from .coordinator import UltraheatCoordinator
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -27,22 +25,11 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     reader = ultraheat_api.UltraheatReader(entry.data[CONF_DEVICE])
     api = ultraheat_api.HeatMeterService(reader)
 
-    async def async_update_data() -> HeatMeterResponse:
-        """Fetch data from the API."""
-        _LOGGER.debug("Polling on %s", entry.data[CONF_DEVICE])
-        return await hass.async_add_executor_job(api.read)
-
-    # Polling is only daily to prevent battery drain.
-    coordinator = DataUpdateCoordinator(
-        hass,
-        _LOGGER,
-        name="ultraheat_gateway",
-        update_method=async_update_data,
-        update_interval=timedelta(days=1),
-    )
+    coordinator = UltraheatCoordinator(hass, api)
 
     hass.data.setdefault(DOMAIN, {})[entry.entry_id] = coordinator
 
+    await coordinator.async_config_entry_first_refresh()
     await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
     return True
