@@ -99,8 +99,10 @@ async def async_setup_entry(
         return False
     except pypck.connection.PchkLicenseError:
         _LOGGER.warning(
-            'Maximum number of connections on PCHK "%s" was '
-            "reached. An additional license key is required",
+            (
+                'Maximum number of connections on PCHK "%s" was '
+                "reached. An additional license key is required"
+            ),
             config_entry.title,
         )
         return False
@@ -269,7 +271,10 @@ class LcnEntity(Entity):
     def device_info(self) -> DeviceInfo | None:
         """Return device specific attributes."""
         address = f"{'g' if self.address[2] else 'm'}{self.address[0]:03d}{self.address[1]:03d}"
-        model = f"LCN resource ({get_device_model(self.config[CONF_DOMAIN], self.config[CONF_DOMAIN_DATA])})"
+        model = (
+            "LCN resource"
+            f" ({get_device_model(self.config[CONF_DOMAIN], self.config[CONF_DOMAIN_DATA])})"
+        )
 
         return {
             "identifiers": {(DOMAIN, self.unique_id)},
