@@ -260,7 +260,9 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 pass
             except ValueError:
                 _LOGGER.warning(
-                    "Invalid RGB color value received for entity %s", self.entity_id
+                    "Invalid RGB color value '%s' received for entity %s",
+                    values,
+                    self.entity_id,
                 )
                 return
 
@@ -272,7 +274,9 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 pass
             except ValueError:
                 _LOGGER.warning(
-                    "Invalid XY color value received for entity %s", self.entity_id
+                    "Invalid XY color value '%s' received for entity %s",
+                    values,
+                    self.entity_id,
                 )
                 return
 
@@ -284,14 +288,18 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                 pass
             except ValueError:
                 _LOGGER.warning(
-                    "Invalid HS color value received for entity %s", self.entity_id
+                    "Invalid HS color value '%s' received for entity %s",
+                    values,
+                    self.entity_id,
                 )
                 return
         else:
             color_mode: str = values["color_mode"]
             if not self._supports_color_mode(color_mode):
                 _LOGGER.warning(
-                    "Invalid color mode received for entity %s", self.entity_id
+                    "Invalid color mode '%s' received for entity %s",
+                    color_mode,
+                    self.entity_id,
                 )
                 return
             try:
@@ -333,7 +341,8 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                     self._attr_xy_color = (x, y)
             except (KeyError, ValueError):
                 _LOGGER.warning(
-                    "Invalid or incomplete color value received for entity %s",
+                    "Invalid or incomplete color value '%s' received for entity %s",
+                    values,
                     self.entity_id,
                 )
 
@@ -378,7 +387,8 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                     pass
                 except (TypeError, ValueError):
                     _LOGGER.warning(
-                        "Invalid brightness value received for entity %s",
+                        "Invalid brightness value '%s' received for entity %s",
+                        values["brightness"],
                         self.entity_id,
                     )
 
@@ -397,7 +407,8 @@ class MqttLightJson(MqttEntity, LightEntity, RestoreEntity):
                     pass
                 except ValueError:
                     _LOGGER.warning(
-                        "Invalid color temp value received for entity %s",
+                        "Invalid color temp value '%s' received for entity %s",
+                        values["color_temp"],
                         self.entity_id,
                     )
 
