@@ -12,9 +12,9 @@ from nextdns import ApiError, Settings
 
 from homeassistant.components.switch import SwitchEntity, SwitchEntityDescription
 from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import EntityCategory
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
@@ -41,156 +41,156 @@ class NextDnsSwitchEntityDescription(
 SWITCHES = (
     NextDnsSwitchEntityDescription[Settings](
         key="block_page",
-        name="Block page",
+        translation_key="block_page",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:web-cancel",
         state=lambda data: data.block_page,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="cache_boost",
-        name="Cache boost",
+        translation_key="cache_boost",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:memory",
         state=lambda data: data.cache_boost,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="cname_flattening",
-        name="CNAME flattening",
+        translation_key="cname_flattening",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:tournament",
         state=lambda data: data.cname_flattening,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="anonymized_ecs",
-        name="Anonymized EDNS client subnet",
+        translation_key="anonymized_ecs",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:incognito",
         state=lambda data: data.anonymized_ecs,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="logs",
-        name="Logs",
+        translation_key="logs",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:file-document-outline",
         state=lambda data: data.logs,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="web3",
-        name="Web3",
+        translation_key="web3",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:web",
         state=lambda data: data.web3,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="allow_affiliate",
-        name="Allow affiliate & tracking links",
+        translation_key="allow_affiliate",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.allow_affiliate,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_disguised_trackers",
-        name="Block disguised third-party trackers",
+        translation_key="block_disguised_trackers",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_disguised_trackers,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="ai_threat_detection",
-        name="AI-Driven threat detection",
+        translation_key="ai_threat_detection",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.ai_threat_detection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_csam",
-        name="Block child sexual abuse material",
+        translation_key="block_csam",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_csam,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_ddns",
-        name="Block dynamic DNS hostnames",
+        translation_key="block_ddns",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_ddns,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_nrd",
-        name="Block newly registered domains",
+        translation_key="block_nrd",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_nrd,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_parked_domains",
-        name="Block parked domains",
+        translation_key="block_parked_domains",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_parked_domains,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="cryptojacking_protection",
-        name="Cryptojacking protection",
+        translation_key="cryptojacking_protection",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.cryptojacking_protection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="dga_protection",
-        name="Domain generation algorithms protection",
+        translation_key="dga_protection",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.dga_protection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="dns_rebinding_protection",
-        name="DNS rebinding protection",
+        translation_key="dns_rebinding_protection",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:dns",
         state=lambda data: data.dns_rebinding_protection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="google_safe_browsing",
-        name="Google safe browsing",
+        translation_key="google_safe_browsing",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:google",
         state=lambda data: data.google_safe_browsing,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="idn_homograph_attacks_protection",
-        name="IDN homograph attacks protection",
+        translation_key="idn_homograph_attacks_protection",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.idn_homograph_attacks_protection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="threat_intelligence_feeds",
-        name="Threat intelligence feeds",
+        translation_key="threat_intelligence_feeds",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.threat_intelligence_feeds,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="typosquatting_protection",
-        name="Typosquatting protection",
+        translation_key="typosquatting_protection",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:keyboard-outline",
         state=lambda data: data.typosquatting_protection,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_bypass_methods",
-        name="Block bypass methods",
+        translation_key="block_bypass_methods",
         entity_category=EntityCategory.CONFIG,
         state=lambda data: data.block_bypass_methods,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="safesearch",
-        name="Force SafeSearch",
+        translation_key="safesearch",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:search-web",
         state=lambda data: data.safesearch,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="youtube_restricted_mode",
-        name="Force YouTube restricted mode",
+        translation_key="youtube_restricted_mode",
         entity_category=EntityCategory.CONFIG,
         icon="mdi:youtube",
         state=lambda data: data.youtube_restricted_mode,
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_9gag",
-        name="Block 9GAG",
+        translation_key="block_9gag",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:file-gif-box",
@@ -198,7 +198,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_amazon",
-        name="Block Amazon",
+        translation_key="block_amazon",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:cart-outline",
@@ -206,7 +206,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_blizzard",
-        name="Block Blizzard",
+        translation_key="block_blizzard",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:sword-cross",
@@ -214,7 +214,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_dailymotion",
-        name="Block Dailymotion",
+        translation_key="block_dailymotion",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:movie-search-outline",
@@ -222,7 +222,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_discord",
-        name="Block Discord",
+        translation_key="block_discord",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:message-text",
@@ -230,7 +230,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_disneyplus",
-        name="Block Disney Plus",
+        translation_key="block_disneyplus",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:movie-search-outline",
@@ -238,7 +238,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_ebay",
-        name="Block eBay",
+        translation_key="block_ebay",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:basket-outline",
@@ -246,7 +246,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_facebook",
-        name="Block Facebook",
+        translation_key="block_facebook",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:facebook",
@@ -254,7 +254,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_fortnite",
-        name="Block Fortnite",
+        translation_key="block_fortnite",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:tank",
@@ -270,7 +270,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_imgur",
-        name="Block Imgur",
+        translation_key="block_imgur",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:camera-image",
@@ -278,7 +278,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_instagram",
-        name="Block Instagram",
+        translation_key="block_instagram",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:instagram",
@@ -286,7 +286,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_leagueoflegends",
-        name="Block League of Legends",
+        translation_key="block_leagueoflegends",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:sword",
@@ -294,7 +294,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_messenger",
-        name="Block Messenger",
+        translation_key="block_messenger",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:message-text",
@@ -302,7 +302,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_minecraft",
-        name="Block Minecraft",
+        translation_key="block_minecraft",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:minecraft",
@@ -310,7 +310,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_netflix",
-        name="Block Netflix",
+        translation_key="block_netflix",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:netflix",
@@ -318,7 +318,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_pinterest",
-        name="Block Pinterest",
+        translation_key="block_pinterest",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:pinterest",
@@ -326,7 +326,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_primevideo",
-        name="Block Prime Video",
+        translation_key="block_primevideo",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:filmstrip",
@@ -334,7 +334,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_reddit",
-        name="Block Reddit",
+        translation_key="block_reddit",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:reddit",
@@ -342,7 +342,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_roblox",
-        name="Block Roblox",
+        translation_key="block_roblox",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:robot",
@@ -350,7 +350,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_signal",
-        name="Block Signal",
+        translation_key="block_signal",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:chat-outline",
@@ -358,7 +358,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_skype",
-        name="Block Skype",
+        translation_key="block_skype",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:skype",
@@ -366,7 +366,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_snapchat",
-        name="Block Snapchat",
+        translation_key="block_snapchat",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:snapchat",
@@ -374,7 +374,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_spotify",
-        name="Block Spotify",
+        translation_key="block_spotify",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:spotify",
@@ -382,7 +382,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_steam",
-        name="Block Steam",
+        translation_key="block_steam",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:steam",
@@ -390,7 +390,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_telegram",
-        name="Block Telegram",
+        translation_key="block_telegram",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:send-outline",
@@ -398,7 +398,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_tiktok",
-        name="Block TikTok",
+        translation_key="block_tiktok",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:music-note",
@@ -406,7 +406,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_tinder",
-        name="Block Tinder",
+        translation_key="block_tinder",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:fire",
@@ -414,7 +414,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_tumblr",
-        name="Block Tumblr",
+        translation_key="block_tumblr",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:image-outline",
@@ -422,7 +422,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_twitch",
-        name="Block Twitch",
+        translation_key="block_twitch",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:twitch",
@@ -430,7 +430,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_twitter",
-        name="Block Twitter",
+        translation_key="block_twitter",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:twitter",
@@ -438,7 +438,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_vimeo",
-        name="Block Vimeo",
+        translation_key="block_vimeo",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:vimeo",
@@ -446,7 +446,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_vk",
-        name="Block VK",
+        translation_key="block_vk",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:power-socket-eu",
@@ -454,7 +454,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_whatsapp",
-        name="Block WhatsApp",
+        translation_key="block_whatsapp",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:whatsapp",
@@ -462,7 +462,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_xboxlive",
-        name="Block Xbox Live",
+        translation_key="block_xboxlive",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:microsoft-xbox",
@@ -470,7 +470,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_youtube",
-        name="Block YouTube",
+        translation_key="block_youtube",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:youtube",
@@ -478,7 +478,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_zoom",
-        name="Block Zoom",
+        translation_key="block_zoom",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:video",
@@ -486,7 +486,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_dating",
-        name="Block dating",
+        translation_key="block_dating",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:candelabra",
@@ -494,7 +494,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_gambling",
-        name="Block gambling",
+        translation_key="block_gambling",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:slot-machine",
@@ -502,7 +502,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_piracy",
-        name="Block piracy",
+        translation_key="block_piracy",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:pirate",
@@ -510,7 +510,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_porn",
-        name="Block porn",
+        translation_key="block_porn",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:movie-off",
@@ -518,7 +518,7 @@ SWITCHES = (
     ),
     NextDnsSwitchEntityDescription[Settings](
         key="block_social_networks",
-        name="Block social networks",
+        translation_key="block_social_networks",
         entity_category=EntityCategory.CONFIG,
         entity_registry_enabled_default=False,
         icon="mdi:facebook",
