@@ -19,7 +19,7 @@ from .const import LOGGER
 from .models import Event
 from .parsers import PARSERS
 
-UNHANDLED_TOPICS = set()
+UNHANDLED_TOPICS: set[str] = set()
 SUBSCRIPTION_ERRORS = (
     Fault,
     asyncio.TimeoutError,
@@ -27,6 +27,13 @@ SUBSCRIPTION_ERRORS = (
 )
 
 
+def _stringify_onvif_error(error: Exception) -> str:
+    """Stringify ONVIF error."""
+    if isinstance(error, Fault):
+        return error.message or str(error) or "Device sent empty error"
+    return str(error)
+
+
 class EventManager:
     """ONVIF Event Manager."""
 
@@ -79,30 +86,30 @@ class EventManager:
 
     async def async_start(self) -> bool:
         """Start polling events."""
-        if await self.device.create_pullpoint_subscription():
-            # Create subscription manager
-            self._subscription = self.device.create_subscription_service(
-                "PullPointSubscription"
-            )
+        if not await self.device.create_pullpoint_subscription():
+            return False
 
-            # Renew immediately
-            await self.async_renew()
+        # Create subscription manager
+        self._subscription = self.device.create_subscription_service(
+            "PullPointSubscription"
+        )
 
-            # Initialize events
-            pullpoint = self.device.create_pullpoint_service()
-            with suppress(*SUBSCRIPTION_ERRORS):
-                await pullpoint.SetSynchronizationPoint()
-            response = await pullpoint.PullMessages(
-                {"MessageLimit": 100, "Timeout": dt.timedelta(seconds=5)}
-            )
+        # Renew immediately
+        await self.async_renew()
 
-            # Parse event initialization
-            await self.async_parse_messages(response.NotificationMessage)
+        # Initialize events
+        pullpoint = self.device.create_pullpoint_service()
+        with suppress(*SUBSCRIPTION_ERRORS):
+            await pullpoint.SetSynchronizationPoint()
+        response = await pullpoint.PullMessages(
+            {"MessageLimit": 100, "Timeout": dt.timedelta(seconds=5)}
+        )
 
-            self.started = True
-            return True
+        # Parse event initialization
+        await self.async_parse_messages(response.NotificationMessage)
 
-        return False
+        self.started = True
+        return True
 
     async def async_stop(self) -> None:
         """Unsubscribe from events."""
@@ -112,7 +119,8 @@ class EventManager:
         if not self._subscription:
             return
 
-        await self._subscription.Unsubscribe()
+        with suppress(*SUBSCRIPTION_ERRORS):
+            await self._subscription.Unsubscribe()
         self._subscription = None
 
     async def async_restart(self, _now: dt.datetime | None = None) -> None:
@@ -148,7 +156,7 @@ class EventManager:
                     "Retrying later: %s"
                 ),
                 self.unique_id,
-                err,
+                _stringify_onvif_error(err),
             )
 
         if not restarted:
@@ -170,7 +178,11 @@ class EventManager:
             .isoformat(timespec="seconds")
             .replace("+00:00", "Z")
         )
-        await self._subscription.Renew(termination_time)
+        with suppress(*SUBSCRIPTION_ERRORS):
+            # The first time we renew, we may get a Fault error so we
+            # suppress it. The subscription will be restarted in
+            # async_restart later.
+            await self._subscription.Renew(termination_time)
 
     def async_schedule_pull(self) -> None:
         """Schedule async_pull_messages to run."""
@@ -203,7 +215,7 @@ class EventManager:
                         " '%s': %s"
                     ),
                     self.unique_id,
-                    err,
+                    _stringify_onvif_error(err),
                 )
                 # Treat errors as if the camera restarted. Assume that the pullpoint
                 # subscription is no longer valid.
