@@ -3,6 +3,7 @@ import asyncio
 from datetime import date, datetime
 import logging
 
+import async_timeout
 import pyotgw
 import pyotgw.vars as gw_vars
 from serial import SerialException
@@ -112,10 +113,8 @@ async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> b
     config_entry.add_update_listener(options_updated)
 
     try:
-        await asyncio.wait_for(
-            gateway.connect_and_subscribe(),
-            timeout=CONNECTION_TIMEOUT,
-        )
+        async with async_timeout.timeout(CONNECTION_TIMEOUT):
+            await gateway.connect_and_subscribe()
     except (asyncio.TimeoutError, ConnectionError, SerialException) as ex:
         await gateway.cleanup()
         raise ConfigEntryNotReady(
