@@ -42,7 +42,7 @@ from homeassistant.core import (
 from homeassistant.helpers import (
     collection,
     config_validation as cv,
-    entity_registry,
+    entity_registry as er,
     service,
 )
 from homeassistant.helpers.entity_component import EntityComponent
@@ -226,19 +226,22 @@ class PersonStorageCollection(collection.StorageCollection):
         """Load the Storage collection."""
         await super().async_load()
         self.hass.bus.async_listen(
-            entity_registry.EVENT_ENTITY_REGISTRY_UPDATED, self._entity_registry_updated
+            er.EVENT_ENTITY_REGISTRY_UPDATED,
+            self._entity_registry_updated,
+            event_filter=self._entity_registry_filter,
         )
 
-    async def _entity_registry_updated(self, event) -> None:
+    @callback
+    def _entity_registry_filter(self, event: Event) -> bool:
+        """Filter entity registry events."""
+        return (
+            event.data["action"] == "remove"
+            and split_entity_id(event.data[ATTR_ENTITY_ID])[0] == "device_tracker"
+        )
+
+    async def _entity_registry_updated(self, event: Event) -> None:
         """Handle entity registry updated."""
-        if event.data["action"] != "remove":
-            return
-
         entity_id = event.data[ATTR_ENTITY_ID]
-
-        if split_entity_id(entity_id)[0] != "device_tracker":
-            return
-
         for person in list(self.data.values()):
             if entity_id not in person[CONF_DEVICE_TRACKERS]:
                 continue
