@@ -18,7 +18,7 @@ from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_URL, CONF_VERIFY_SSL, EVENT_HOMEASSISTANT_STOP
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import ConfigEntryAuthFailed, ConfigEntryNotReady
-from homeassistant.helpers import device_registry as dev_reg, entity_registry as ent_reg
+from homeassistant.helpers import device_registry as dr, entity_registry as er
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 from homeassistant.helpers.debounce import Debouncer
 from homeassistant.helpers.dispatcher import (
@@ -35,8 +35,6 @@ from .const import (
     CONF_SERVER_IDENTIFIER,
     DISPATCHERS,
     DOMAIN,
-    GDM_DEBOUNCER,
-    GDM_SCANNER,
     PLATFORMS,
     PLATFORMS_COMPLETED,
     PLEX_SERVER_CONFIG,
@@ -47,6 +45,7 @@ from .const import (
     WEBSOCKETS,
 )
 from .errors import ShouldUpdateConfigEntry
+from .helpers import PlexData, get_plex_data
 from .media_browser import browse_media
 from .server import PlexServer
 from .services import async_setup_services
@@ -62,7 +61,7 @@ def is_plex_media_id(media_content_id):
 
 async def async_browse_media(hass, media_content_type, media_content_id, platform=None):
     """Browse Plex media."""
-    plex_server = next(iter(hass.data[DOMAIN][SERVERS].values()), None)
+    plex_server = next(iter(get_plex_data(hass)[SERVERS].values()), None)
     if not plex_server:
         raise BrowseError("No Plex servers available")
     is_internal = is_internal_request(hass)
@@ -80,22 +79,13 @@ async def async_browse_media(hass, media_content_type, media_content_id, platfor
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Set up the Plex component."""
-    hass.data.setdefault(
-        DOMAIN,
-        {SERVERS: {}, DISPATCHERS: {}, WEBSOCKETS: {}, PLATFORMS_COMPLETED: {}},
-    )
-
-    await async_setup_services(hass)
-
-    hass.http.register_view(PlexImageView())
-
-    gdm = hass.data[DOMAIN][GDM_SCANNER] = GDM()
+    gdm = GDM()
 
     def gdm_scan():
         _LOGGER.debug("Scanning for GDM clients")
         gdm.scan(scan_for_clients=True)
 
-    hass.data[DOMAIN][GDM_DEBOUNCER] = Debouncer[None](
+    debouncer = Debouncer[None](
         hass,
         _LOGGER,
         cooldown=10,
@@ -103,6 +93,20 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         function=gdm_scan,
     ).async_call
 
+    hass_data = PlexData(
+        servers={},
+        dispatchers={},
+        websockets={},
+        platforms_completed={},
+        gdm_scanner=gdm,
+        gdm_debouncer=debouncer,
+    )
+    hass.data.setdefault(DOMAIN, hass_data)
+
+    await async_setup_services(hass)
+
+    hass.http.register_view(PlexImageView())
+
     return True
 
 
@@ -161,8 +165,9 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         "Connected to: %s (%s)", plex_server.friendly_name, plex_server.url_in_use
     )
     server_id = plex_server.machine_identifier
-    hass.data[DOMAIN][SERVERS][server_id] = plex_server
-    hass.data[DOMAIN][PLATFORMS_COMPLETED][server_id] = set()
+    hass_data = get_plex_data(hass)
+    hass_data[SERVERS][server_id] = plex_server
+    hass_data[PLATFORMS_COMPLETED][server_id] = set()
 
     entry.add_update_listener(async_options_updated)
 
@@ -171,14 +176,13 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         PLEX_UPDATE_PLATFORMS_SIGNAL.format(server_id),
         plex_server.async_update_platforms,
     )
-    hass.data[DOMAIN][DISPATCHERS].setdefault(server_id, [])
-    hass.data[DOMAIN][DISPATCHERS][server_id].append(unsub)
+    hass_data[DISPATCHERS].setdefault(server_id, [])
+    hass_data[DISPATCHERS][server_id].append(unsub)
 
     @callback
     def plex_websocket_callback(msgtype, data, error):
         """Handle callbacks from plexwebsocket library."""
         if msgtype == SIGNAL_CONNECTION_STATE:
-
             if data == STATE_CONNECTED:
                 _LOGGER.debug("Websocket to %s successful", entry.data[CONF_SERVER])
                 hass.async_create_task(plex_server.async_update_platforms())
@@ -214,11 +218,11 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         session=session,
         verify_ssl=verify_ssl,
     )
-    hass.data[DOMAIN][WEBSOCKETS][server_id] = websocket
+    hass_data[WEBSOCKETS][server_id] = websocket
 
     def start_websocket_session(platform):
-        hass.data[DOMAIN][PLATFORMS_COMPLETED][server_id].add(platform)
-        if hass.data[DOMAIN][PLATFORMS_COMPLETED][server_id] == PLATFORMS:
+        hass_data[PLATFORMS_COMPLETED][server_id].add(platform)
+        if hass_data[PLATFORMS_COMPLETED][server_id] == PLATFORMS:
             hass.loop.create_task(websocket.listen())
 
     def close_websocket_session(_):
@@ -227,7 +231,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     unsub = hass.bus.async_listen_once(
         EVENT_HOMEASSISTANT_STOP, close_websocket_session
     )
-    hass.data[DOMAIN][DISPATCHERS][server_id].append(unsub)
+    hass_data[DISPATCHERS][server_id].append(unsub)
 
     await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
@@ -264,16 +268,17 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
     server_id = entry.data[CONF_SERVER_IDENTIFIER]
 
-    websocket = hass.data[DOMAIN][WEBSOCKETS].pop(server_id)
+    hass_data = get_plex_data(hass)
+    websocket = hass_data[WEBSOCKETS].pop(server_id)
     websocket.close()
 
-    dispatchers = hass.data[DOMAIN][DISPATCHERS].pop(server_id)
+    dispatchers = hass_data[DISPATCHERS].pop(server_id)
     for unsub in dispatchers:
         unsub()
 
     unload_ok = await hass.config_entries.async_unload_platforms(entry, PLATFORMS)
 
-    hass.data[DOMAIN][SERVERS].pop(server_id)
+    hass_data[SERVERS].pop(server_id)
 
     return unload_ok
 
@@ -282,25 +287,24 @@ async def async_options_updated(hass: HomeAssistant, entry: ConfigEntry) -> None
     """Triggered by config entry options updates."""
     server_id = entry.data[CONF_SERVER_IDENTIFIER]
 
+    hass_data = get_plex_data(hass)
     # Guard incomplete setup during reauth flows
-    if server_id in hass.data[DOMAIN][SERVERS]:
-        hass.data[DOMAIN][SERVERS][server_id].options = entry.options
+    if server_id in hass_data[SERVERS]:
+        hass_data[SERVERS][server_id].options = entry.options
 
 
 @callback
 def async_cleanup_plex_devices(hass, entry):
     """Clean up old and invalid devices from the registry."""
-    device_registry = dev_reg.async_get(hass)
-    entity_registry = ent_reg.async_get(hass)
+    device_registry = dr.async_get(hass)
+    entity_registry = er.async_get(hass)
 
-    device_entries = dev_reg.async_entries_for_config_entry(
-        device_registry, entry.entry_id
-    )
+    device_entries = dr.async_entries_for_config_entry(device_registry, entry.entry_id)
 
     for device_entry in device_entries:
         if (
             len(
-                ent_reg.async_entries_for_device(
+                er.async_entries_for_device(
                     entity_registry, device_entry.id, include_disabled_entities=True
                 )
             )
