@@ -51,7 +51,13 @@ async def async_setup_platform(
     add_entities(sensors)
 
 
-def create_binary_sensor(coordinator, host_name, node_name, vm_id, name):
+def create_binary_sensor(
+    coordinator,
+    host_name: str,
+    node_name: str,
+    vm_id: int,
+    name: str,
+) -> ProxmoxBinarySensor:
     """Create a binary sensor based on the given data."""
     return ProxmoxBinarySensor(
         coordinator=coordinator,
@@ -72,12 +78,12 @@ class ProxmoxBinarySensor(ProxmoxEntity, BinarySensorEntity):
     def __init__(
         self,
         coordinator: DataUpdateCoordinator,
-        unique_id,
-        name,
-        icon,
-        host_name,
-        node_name,
-        vm_id,
+        unique_id: str,
+        name: str,
+        icon: str,
+        host_name: str,
+        node_name: str,
+        vm_id: int,
     ) -> None:
         """Create the binary sensor for vms or containers."""
         super().__init__(
@@ -85,7 +91,7 @@ class ProxmoxBinarySensor(ProxmoxEntity, BinarySensorEntity):
         )
 
     @property
-    def is_on(self):
+    def is_on(self) -> bool | None:
         """Return the state of the binary sensor."""
         if (data := self.coordinator.data) is None:
             return None
