@@ -37,6 +37,7 @@ from .statistics import (
     async_add_external_statistics,
     async_change_statistics_unit,
     async_import_statistics,
+    async_list_statistic_ids,
     list_statistic_ids,
     statistic_during_period,
     statistics_during_period,
@@ -151,7 +152,7 @@ def _ws_get_statistics_during_period(
     msg_id: int,
     start_time: dt,
     end_time: dt | None,
-    statistic_ids: list[str] | None,
+    statistic_ids: set[str] | None,
     period: Literal["5minute", "day", "hour", "week", "month"],
     units: dict[str, str],
     types: set[Literal["last_reset", "max", "mean", "min", "state", "sum"]],
@@ -208,7 +209,7 @@ async def ws_handle_get_statistics_during_period(
             msg["id"],
             start_time,
             end_time,
-            msg["statistic_ids"],
+            set(msg["statistic_ids"]),
             msg.get("period"),
             msg.get("units"),
             types,
@@ -329,11 +330,10 @@ async def ws_get_statistics_metadata(
     hass: HomeAssistant, connection: websocket_api.ActiveConnection, msg: dict[str, Any]
 ) -> None:
     """Get metadata for a list of statistic_ids."""
-    instance = get_instance(hass)
-    statistic_ids = await instance.async_add_executor_job(
-        list_statistic_ids, hass, msg.get("statistic_ids")
-    )
-    connection.send_result(msg["id"], statistic_ids)
+    statistic_ids = msg.get("statistic_ids")
+    statistic_ids_set_or_none = set(statistic_ids) if statistic_ids else None
+    metadata = await async_list_statistic_ids(hass, statistic_ids_set_or_none)
+    connection.send_result(msg["id"], metadata)
 
 
 @websocket_api.require_admin
@@ -413,7 +413,7 @@ async def ws_adjust_sum_statistics(
 
     instance = get_instance(hass)
     metadatas = await instance.async_add_executor_job(
-        list_statistic_ids, hass, (msg["statistic_id"],)
+        list_statistic_ids, hass, {msg["statistic_id"]}
     )
     if not metadatas:
         connection.send_error(msg["id"], "unknown_statistic_id", "Unknown statistic ID")
