@@ -62,13 +62,20 @@ BUTTON_TYPES: tuple[RenaultButtonEntityDescription, ...] = (
         async_press=lambda x: x.vehicle.set_ac_start(21, None),
         key="start_air_conditioner",
         icon="mdi:air-conditioner",
-        name="Start air conditioner",
+        translation_key="start_air_conditioner",
     ),
     RenaultButtonEntityDescription(
         async_press=lambda x: x.vehicle.set_charge_start(),
         key="start_charge",
         icon="mdi:ev-station",
-        name="Start charge",
         requires_electricity=True,
+        translation_key="start_charge",
+    ),
+    RenaultButtonEntityDescription(
+        async_press=lambda x: x.vehicle.set_charge_stop(),
+        key="stop_charge",
+        icon="mdi:ev-station",
+        requires_electricity=True,
+        translation_key="stop_charge",
     ),
 )
