@@ -5,21 +5,24 @@ from collections.abc import Mapping
 import logging
 from typing import Any
 
-from reolink_aio.exceptions import ApiError, CredentialsInvalidError
+from reolink_aio.exceptions import ApiError, CredentialsInvalidError, ReolinkError
 import voluptuous as vol
 
-from homeassistant import config_entries, exceptions
+from homeassistant import config_entries
+from homeassistant.components import dhcp
 from homeassistant.const import CONF_HOST, CONF_PASSWORD, CONF_PORT, CONF_USERNAME
 from homeassistant.core import callback
 from homeassistant.data_entry_flow import FlowResult
 from homeassistant.helpers import config_validation as cv
+from homeassistant.helpers.device_registry import format_mac
 
-from .const import CONF_PROTOCOL, CONF_USE_HTTPS, DEFAULT_PROTOCOL, DOMAIN
-from .exceptions import UserNotAdmin
+from .const import CONF_PROTOCOL, CONF_USE_HTTPS, DOMAIN
+from .exceptions import ReolinkException, UserNotAdmin
 from .host import ReolinkHost
 
 _LOGGER = logging.getLogger(__name__)
 
+DEFAULT_PROTOCOL = "rtsp"
 DEFAULT_OPTIONS = {CONF_PROTOCOL: DEFAULT_PROTOCOL}
 
 
@@ -44,7 +47,7 @@ class ReolinkOptionsFlowHandler(config_entries.OptionsFlow):
                     vol.Required(
                         CONF_PROTOCOL,
                         default=self.config_entry.options[CONF_PROTOCOL],
-                    ): vol.In(["rtsp", "rtmp"]),
+                    ): vol.In(["rtsp", "rtmp", "flv"]),
                 }
             ),
         )
@@ -86,32 +89,55 @@ class ReolinkFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
             return await self.async_step_user()
         return self.async_show_form(step_id="reauth_confirm")
 
+    async def async_step_dhcp(self, discovery_info: dhcp.DhcpServiceInfo) -> FlowResult:
+        """Handle discovery via dhcp."""
+        mac_address = format_mac(discovery_info.macaddress)
+        await self.async_set_unique_id(mac_address)
+        self._abort_if_unique_id_configured(updates={CONF_HOST: discovery_info.ip})
+
+        self.context["title_placeholders"] = {
+            "ip_address": discovery_info.ip,
+            "hostname": discovery_info.hostname,
+        }
+
+        self._host = discovery_info.ip
+        return await self.async_step_user()
+
     async def async_step_user(
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
         """Handle the initial step."""
         errors = {}
-        placeholders = {"error": ""}
+        placeholders = {
+            "error": "",
+            "troubleshooting_link": "https://www.home-assistant.io/integrations/reolink/#troubleshooting",
+        }
 
         if user_input is not None:
+            if CONF_HOST not in user_input:
+                user_input[CONF_HOST] = self._host
+
             host = ReolinkHost(self.hass, user_input, DEFAULT_OPTIONS)
             try:
-                await async_obtain_host_settings(host)
+                await host.async_init()
             except UserNotAdmin:
                 errors[CONF_USERNAME] = "not_admin"
                 placeholders["username"] = host.api.username
                 placeholders["userlevel"] = host.api.user_level
-            except CannotConnect:
-                errors[CONF_HOST] = "cannot_connect"
             except CredentialsInvalidError:
                 errors[CONF_HOST] = "invalid_auth"
             except ApiError as err:
                 placeholders["error"] = str(err)
                 errors[CONF_HOST] = "api_error"
+            except (ReolinkError, ReolinkException) as err:
+                placeholders["error"] = str(err)
+                errors[CONF_HOST] = "cannot_connect"
             except Exception as err:  # pylint: disable=broad-except
                 _LOGGER.exception("Unexpected exception")
                 placeholders["error"] = str(err)
                 errors[CONF_HOST] = "unknown"
+            finally:
+                await host.stop()
 
             if not errors:
                 user_input[CONF_PORT] = host.api.port
@@ -140,9 +166,14 @@ class ReolinkFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
             {
                 vol.Required(CONF_USERNAME, default=self._username): str,
                 vol.Required(CONF_PASSWORD, default=self._password): str,
-                vol.Required(CONF_HOST, default=self._host): str,
             }
         )
+        if self._host is None or errors:
+            data_schema = data_schema.extend(
+                {
+                    vol.Required(CONF_HOST, default=self._host): str,
+                }
+            )
         if errors:
             data_schema = data_schema.extend(
                 {
@@ -157,16 +188,3 @@ class ReolinkFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
             errors=errors,
             description_placeholders=placeholders,
         )
-
-
-async def async_obtain_host_settings(host: ReolinkHost) -> None:
-    """Initialize the Reolink host and get the host information."""
-    try:
-        if not await host.async_init():
-            raise CannotConnect
-    finally:
-        await host.stop()
-
-
-class CannotConnect(exceptions.HomeAssistantError):
-    """Error to indicate we cannot connect."""
