@@ -1,4 +1,4 @@
-"""This component encapsulates the NVR/camera API and subscription."""
+"""Module which encapsulates the NVR/camera API and subscription."""
 from __future__ import annotations
 
 import asyncio
@@ -54,7 +54,9 @@ class ReolinkHost:
         )
 
         self.webhook_id: str | None = None
-        self._webhook_url: str | None = None
+        self._base_url: str = ""
+        self._webhook_url: str = ""
+        self._webhook_reachable: asyncio.Event = asyncio.Event()
         self._lost_subscription: bool = False
 
     @property
@@ -80,9 +82,15 @@ class ReolinkHost:
                 f"'{self._api.user_level}', only admin users can change camera settings"
             )
 
+        enable_rtsp = None
         enable_onvif = None
         enable_rtmp = None
-        enable_rtsp = None
+
+        if not self._api.rtsp_enabled:
+            _LOGGER.debug(
+                "RTSP is disabled on %s, trying to enable it", self._api.nvr_name
+            )
+            enable_rtsp = True
 
         if not self._api.onvif_enabled:
             _LOGGER.debug(
@@ -95,11 +103,6 @@ class ReolinkHost:
                 "RTMP is disabled on %s, trying to enable it", self._api.nvr_name
             )
             enable_rtmp = True
-        elif not self._api.rtsp_enabled and self._api.protocol == "rtsp":
-            _LOGGER.debug(
-                "RTSP is disabled on %s, trying to enable it", self._api.nvr_name
-            )
-            enable_rtsp = True
 
         if enable_onvif or enable_rtmp or enable_rtsp:
             try:
@@ -109,28 +112,82 @@ class ReolinkHost:
                     enable_rtsp=enable_rtsp,
                 )
             except ReolinkError:
+                ports = ""
+                if enable_rtsp:
+                    ports += "RTSP "
+
                 if enable_onvif:
-                    _LOGGER.error(
-                        "Failed to enable ONVIF on %s. "
-                        "Set it to ON to receive notifications",
-                        self._api.nvr_name,
-                    )
+                    ports += "ONVIF "
 
                 if enable_rtmp:
-                    _LOGGER.error(
-                        "Failed to enable RTMP on %s. Set it to ON",
-                        self._api.nvr_name,
-                    )
-                elif enable_rtsp:
-                    _LOGGER.error(
-                        "Failed to enable RTSP on %s. Set it to ON",
-                        self._api.nvr_name,
-                    )
+                    ports += "RTMP "
+
+                ir.async_create_issue(
+                    self._hass,
+                    DOMAIN,
+                    "enable_port",
+                    is_fixable=False,
+                    severity=ir.IssueSeverity.WARNING,
+                    translation_key="enable_port",
+                    translation_placeholders={
+                        "name": self._api.nvr_name,
+                        "ports": ports,
+                        "info_link": "https://support.reolink.com/hc/en-us/articles/900004435763-How-to-Set-up-Reolink-Ports-Settings-via-Reolink-Client-New-Client-",
+                    },
+                )
+        else:
+            ir.async_delete_issue(self._hass, DOMAIN, "enable_port")
 
         self._unique_id = format_mac(self._api.mac_address)
 
         await self.subscribe()
 
+        _LOGGER.debug(
+            "Waiting for initial ONVIF state on webhook '%s'", self._webhook_url
+        )
+        try:
+            await asyncio.wait_for(self._webhook_reachable.wait(), timeout=15)
+        except asyncio.TimeoutError:
+            _LOGGER.debug(
+                "Did not receive initial ONVIF state on webhook '%s' after 15 seconds",
+                self._webhook_url,
+            )
+            ir.async_create_issue(
+                self._hass,
+                DOMAIN,
+                "webhook_url",
+                is_fixable=False,
+                severity=ir.IssueSeverity.WARNING,
+                translation_key="webhook_url",
+                translation_placeholders={
+                    "name": self._api.nvr_name,
+                    "base_url": self._base_url,
+                    "network_link": "https://my.home-assistant.io/redirect/network/",
+                },
+            )
+        else:
+            ir.async_delete_issue(self._hass, DOMAIN, "webhook_url")
+
+        if self._api.sw_version_update_required:
+            ir.async_create_issue(
+                self._hass,
+                DOMAIN,
+                "firmware_update",
+                is_fixable=False,
+                severity=ir.IssueSeverity.WARNING,
+                translation_key="firmware_update",
+                translation_placeholders={
+                    "required_firmware": self._api.sw_version_required.version_string,
+                    "current_firmware": self._api.sw_version,
+                    "model": self._api.model,
+                    "hw_version": self._api.hardware_version,
+                    "name": self._api.nvr_name,
+                    "download_link": "https://reolink.com/download-center/",
+                },
+            )
+        else:
+            ir.async_delete_issue(self._hass, DOMAIN, "firmware_update")
+
     async def update_states(self) -> None:
         """Call the API of the camera device to update the internal states."""
         await self._api.get_states()
@@ -260,10 +317,10 @@ class ReolinkHost:
         )
 
         try:
-            base_url = get_url(self._hass, prefer_external=False)
+            self._base_url = get_url(self._hass, prefer_external=False)
         except NoURLAvailableError:
             try:
-                base_url = get_url(self._hass, prefer_external=True)
+                self._base_url = get_url(self._hass, prefer_external=True)
             except NoURLAvailableError as err:
                 self.unregister_webhook()
                 raise ReolinkWebhookException(
@@ -272,9 +329,9 @@ class ReolinkHost:
                 ) from err
 
         webhook_path = webhook.async_generate_path(event_id)
-        self._webhook_url = f"{base_url}{webhook_path}"
+        self._webhook_url = f"{self._base_url}{webhook_path}"
 
-        if base_url.startswith("https"):
+        if self._base_url.startswith("https"):
             ir.async_create_issue(
                 self._hass,
                 DOMAIN,
@@ -283,7 +340,7 @@ class ReolinkHost:
                 severity=ir.IssueSeverity.WARNING,
                 translation_key="https_webhook",
                 translation_placeholders={
-                    "base_url": base_url,
+                    "base_url": self._base_url,
                     "network_link": "https://my.home-assistant.io/redirect/network/",
                 },
             )
@@ -300,10 +357,18 @@ class ReolinkHost:
 
     async def handle_webhook(
         self, hass: HomeAssistant, webhook_id: str, request: Request
+    ):
+        """Shield the incoming webhook callback from cancellation."""
+        await asyncio.shield(self.handle_webhook_shielded(hass, webhook_id, request))
+
+    async def handle_webhook_shielded(
+        self, hass: HomeAssistant, webhook_id: str, request: Request
     ):
         """Handle incoming webhook from Reolink for inbound messages and calls."""
 
         _LOGGER.debug("Webhook '%s' called", webhook_id)
+        if not self._webhook_reachable.is_set():
+            self._webhook_reachable.set()
 
         if not request.body_exists:
             _LOGGER.debug("Webhook '%s' triggered without payload", webhook_id)
