@@ -1,4 +1,4 @@
-"""This component provides HA sensor support for Ring Door Bell/Chimes."""
+"""Component providing HA sensor support for Ring Door Bell/Chimes."""
 from __future__ import annotations
 
 from dataclasses import dataclass
@@ -80,7 +80,7 @@ class RingBinarySensor(RingEntityMixin, BinarySensorEntity):
         ring,
         device,
         description: RingBinarySensorEntityDescription,
-    ):
+    ) -> None:
         """Initialize a sensor for Ring device."""
         super().__init__(config_entry_id, device)
         self.entity_description = description
