@@ -4,23 +4,17 @@ from __future__ import annotations
 from datetime import date, datetime
 
 import ephem
-import voluptuous as vol
 
-from homeassistant.components.sensor import (
-    PLATFORM_SCHEMA as PARENT_PLATFORM_SCHEMA,
-    SensorEntity,
-)
-from homeassistant.config_entries import SOURCE_IMPORT, ConfigEntry
-from homeassistant.const import CONF_NAME, CONF_TYPE
+from homeassistant.components.sensor import SensorDeviceClass, SensorEntity
+from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import CONF_TYPE
 from homeassistant.core import HomeAssistant
-import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.device_registry import DeviceEntryType
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 from homeassistant.util.dt import utcnow
 
-from .const import DEFAULT_NAME, DOMAIN, TYPE_ASTRONOMICAL, VALID_TYPES
+from .const import DOMAIN, TYPE_ASTRONOMICAL
 
 EQUATOR = "equator"
 
@@ -47,30 +41,6 @@ SEASON_ICONS = {
 }
 
 
-PLATFORM_SCHEMA = PARENT_PLATFORM_SCHEMA.extend(
-    {
-        vol.Optional(CONF_TYPE, default=TYPE_ASTRONOMICAL): vol.In(VALID_TYPES),
-        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    }
-)
-
-
-async def async_setup_platform(
-    hass: HomeAssistant,
-    config: ConfigType,
-    async_add_entities: AddEntitiesCallback,
-    discovery_info: DiscoveryInfoType | None = None,
-) -> None:
-    """Set up the season sensor platform."""
-    hass.async_create_task(
-        hass.config_entries.flow.async_init(
-            DOMAIN,
-            context={"source": SOURCE_IMPORT},
-            data=config,
-        )
-    )
-
-
 async def async_setup_entry(
     hass: HomeAssistant,
     entry: ConfigEntry,
@@ -122,8 +92,10 @@ def get_season(
 class SeasonSensorEntity(SensorEntity):
     """Representation of the current season."""
 
-    _attr_device_class = "season__season"
+    _attr_device_class = SensorDeviceClass.ENUM
     _attr_has_entity_name = True
+    _attr_options = ["spring", "summer", "autumn", "winter"]
+    _attr_translation_key = "season"
 
     def __init__(self, entry: ConfigEntry, hemisphere: str) -> None:
         """Initialize the season."""
@@ -131,7 +103,7 @@ class SeasonSensorEntity(SensorEntity):
         self.hemisphere = hemisphere
         self.type = entry.data[CONF_TYPE]
         self._attr_device_info = DeviceInfo(
-            name=entry.title,
+            name="Season",
             identifiers={(DOMAIN, entry.entry_id)},
             entry_type=DeviceEntryType.SERVICE,
         )
