@@ -19,20 +19,20 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN
 from .coordinator import SensiboDataUpdateCoordinator
-from .entity import SensiboDeviceBaseEntity
+from .entity import SensiboDeviceBaseEntity, async_handle_api_call
 
 PARALLEL_UPDATES = 0
 
 
 @dataclass
 class DeviceBaseEntityDescriptionMixin:
-    """Mixin for required Sensibo base description keys."""
+    """Mixin for required Sensibo Device description keys."""
 
     value_fn: Callable[[SensiboDevice], bool | None]
     extra_fn: Callable[[SensiboDevice], dict[str, str | bool | None]] | None
     command_on: str
     command_off: str
-    remote_key: str
+    data_key: str
 
 
 @dataclass
@@ -50,9 +50,20 @@ DEVICE_SWITCH_TYPES: tuple[SensiboDeviceSwitchEntityDescription, ...] = (
         icon="mdi:timer",
         value_fn=lambda data: data.timer_on,
         extra_fn=lambda data: {"id": data.timer_id, "turn_on": data.timer_state_on},
-        command_on="set_timer",
-        command_off="del_timer",
-        remote_key="timer_on",
+        command_on="async_turn_on_timer",
+        command_off="async_turn_off_timer",
+        data_key="timer_on",
+    ),
+    SensiboDeviceSwitchEntityDescription(
+        key="climate_react_switch",
+        device_class=SwitchDeviceClass.SWITCH,
+        name="Climate React",
+        icon="mdi:wizard-hat",
+        value_fn=lambda data: data.smart_on,
+        extra_fn=lambda data: {"type": data.smart_type},
+        command_on="async_turn_on_off_smart",
+        command_off="async_turn_on_off_smart",
+        data_key="smart_on",
     ),
 )
 
@@ -63,58 +74,29 @@ PURE_SWITCH_TYPES: tuple[SensiboDeviceSwitchEntityDescription, ...] = (
         name="Pure Boost",
         value_fn=lambda data: data.pure_boost_enabled,
         extra_fn=None,
-        command_on="set_pure_boost",
-        command_off="set_pure_boost",
-        remote_key="pure_boost_enabled",
+        command_on="async_turn_on_off_pure_boost",
+        command_off="async_turn_on_off_pure_boost",
+        data_key="pure_boost_enabled",
     ),
 )
 
-
-def build_params(command: str, device_data: SensiboDevice) -> dict[str, Any] | None:
-    """Build params for turning on switch."""
-    if command == "set_timer":
-        new_state = bool(device_data.ac_states["on"] is False)
-        params = {
-            "minutesFromNow": 60,
-            "acState": {**device_data.ac_states, "on": new_state},
-        }
-        return params
-    if command == "set_pure_boost":
-        new_state = bool(device_data.pure_boost_enabled is False)
-        params = {"enabled": new_state}
-        if device_data.pure_measure_integration is None:
-            params["sensitivity"] = "N"
-            params["measurementsIntegration"] = True
-            params["acIntegration"] = False
-            params["geoIntegration"] = False
-            params["primeIntegration"] = False
-        return params
-    return None
+DESCRIPTION_BY_MODELS = {"pure": PURE_SWITCH_TYPES}
 
 
 async def async_setup_entry(
     hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
 ) -> None:
-    """Set up Sensibo binary sensor platform."""
+    """Set up Sensibo Switch platform."""
 
     coordinator: SensiboDataUpdateCoordinator = hass.data[DOMAIN][entry.entry_id]
 
-    entities: list[SensiboDeviceSwitch] = []
-
-    entities.extend(
+    async_add_entities(
         SensiboDeviceSwitch(coordinator, device_id, description)
-        for description in DEVICE_SWITCH_TYPES
         for device_id, device_data in coordinator.data.parsed.items()
-        if device_data.model != "pure"
+        for description in DESCRIPTION_BY_MODELS.get(
+            device_data.model, DEVICE_SWITCH_TYPES
+        )
     )
-    entities.extend(
-        SensiboDeviceSwitch(coordinator, device_id, description)
-        for description in PURE_SWITCH_TYPES
-        for device_id, device_data in coordinator.data.parsed.items()
-        if device_data.model == "pure"
-    )
-
-    async_add_entities(entities)
 
 
 class SensiboDeviceSwitch(SensiboDeviceBaseEntity, SwitchEntity):
@@ -143,32 +125,20 @@ class SensiboDeviceSwitch(SensiboDeviceBaseEntity, SwitchEntity):
 
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Turn the entity on."""
-        params = build_params(self.entity_description.command_on, self.device_data)
-        result = await self.async_send_command(
-            self.entity_description.command_on, params
-        )
-
-        if result["status"] == "success":
-            setattr(self.device_data, self.entity_description.remote_key, True)
-            self.async_write_ha_state()
-            return await self.coordinator.async_request_refresh()
-        raise HomeAssistantError(
-            f"Could not execute {self.entity_description.command_on} for device {self.name}"
+        func = getattr(SensiboDeviceSwitch, self.entity_description.command_on)
+        await func(
+            self,
+            key=self.entity_description.data_key,
+            value=True,
         )
 
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the entity off."""
-        params = build_params(self.entity_description.command_on, self.device_data)
-        result = await self.async_send_command(
-            self.entity_description.command_off, params
-        )
-
-        if result["status"] == "success":
-            setattr(self.device_data, self.entity_description.remote_key, False)
-            self.async_write_ha_state()
-            return await self.coordinator.async_request_refresh()
-        raise HomeAssistantError(
-            f"Could not execute {self.entity_description.command_off} for device {self.name}"
+        func = getattr(SensiboDeviceSwitch, self.entity_description.command_off)
+        await func(
+            self,
+            key=self.entity_description.data_key,
+            value=True,
         )
 
     @property
@@ -177,3 +147,47 @@ class SensiboDeviceSwitch(SensiboDeviceBaseEntity, SwitchEntity):
         if self.entity_description.extra_fn:
             return self.entity_description.extra_fn(self.device_data)
         return None
+
+    @async_handle_api_call
+    async def async_turn_on_timer(self, key: str, value: Any) -> bool:
+        """Make service call to api for setting timer."""
+        new_state = bool(self.device_data.ac_states["on"] is False)
+        data = {
+            "minutesFromNow": 60,
+            "acState": {**self.device_data.ac_states, "on": new_state},
+        }
+        result = await self._client.async_set_timer(self._device_id, data)
+        return bool(result.get("status") == "success")
+
+    @async_handle_api_call
+    async def async_turn_off_timer(self, key: str, value: Any) -> bool:
+        """Make service call to api for deleting timer."""
+        result = await self._client.async_del_timer(self._device_id)
+        return bool(result.get("status") == "success")
+
+    @async_handle_api_call
+    async def async_turn_on_off_pure_boost(self, key: str, value: Any) -> bool:
+        """Make service call to api for setting Pure Boost."""
+        new_state = bool(self.device_data.pure_boost_enabled is False)
+        data: dict[str, Any] = {"enabled": new_state}
+        if self.device_data.pure_measure_integration is None:
+            data["sensitivity"] = "N"
+            data["measurementsIntegration"] = True
+            data["acIntegration"] = False
+            data["geoIntegration"] = False
+            data["primeIntegration"] = False
+        result = await self._client.async_set_pureboost(self._device_id, data)
+        return bool(result.get("status") == "success")
+
+    @async_handle_api_call
+    async def async_turn_on_off_smart(self, key: str, value: Any) -> bool:
+        """Make service call to api for setting Climate React."""
+        if self.device_data.smart_type is None:
+            raise HomeAssistantError(
+                "Use Sensibo Enable Climate React Service once to enable switch or the"
+                " Sensibo app"
+            )
+        new_state = bool(self.device_data.smart_on is False)
+        data: dict[str, Any] = {"enabled": new_state}
+        result = await self._client.async_enable_climate_react(self._device_id, data)
+        return bool(result.get("status") == "success")
