@@ -1,4 +1,6 @@
 """The slack integration."""
+from __future__ import annotations
+
 import logging
 
 from aiohttp.client_exceptions import ClientError
@@ -10,13 +12,23 @@ from homeassistant.const import CONF_API_KEY, CONF_PLATFORM, Platform
 from homeassistant.core import HomeAssistant
 from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import aiohttp_client, discovery
+from homeassistant.helpers.device_registry import DeviceEntryType
+from homeassistant.helpers.entity import DeviceInfo, Entity, EntityDescription
 from homeassistant.helpers.typing import ConfigType
 
-from .const import DATA_CLIENT, DATA_HASS_CONFIG, DOMAIN
+from .const import (
+    ATTR_URL,
+    ATTR_USER_ID,
+    DATA_CLIENT,
+    DATA_HASS_CONFIG,
+    DEFAULT_NAME,
+    DOMAIN,
+    SLACK_DATA,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-PLATFORMS = [Platform.NOTIFY]
+PLATFORMS = [Platform.NOTIFY, Platform.SENSOR]
 
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
@@ -42,14 +54,18 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     slack = WebClient(token=entry.data[CONF_API_KEY], run_async=True, session=session)
 
     try:
-        await slack.auth_test()
+        res = await slack.auth_test()
     except (SlackApiError, ClientError) as ex:
         if isinstance(ex, SlackApiError) and ex.response["error"] == "invalid_auth":
             _LOGGER.error("Invalid API key")
             return False
         raise ConfigEntryNotReady("Error while setting up integration") from ex
-
-    hass.data.setdefault(DOMAIN, {})[entry.entry_id] = entry.data | {DATA_CLIENT: slack}
+    data = {
+        DATA_CLIENT: slack,
+        ATTR_URL: res[ATTR_URL],
+        ATTR_USER_ID: res[ATTR_USER_ID],
+    }
+    hass.data.setdefault(DOMAIN, {})[entry.entry_id] = entry.data | {SLACK_DATA: data}
 
     hass.async_create_task(
         discovery.async_load_platform(
@@ -61,4 +77,33 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         )
     )
 
+    await hass.config_entries.async_forward_entry_setups(
+        entry, [platform for platform in PLATFORMS if platform != Platform.NOTIFY]
+    )
+
     return True
+
+
+class SlackEntity(Entity):
+    """Representation of a Slack entity."""
+
+    _attr_attribution = "Data provided by Slack"
+    _attr_has_entity_name = True
+
+    def __init__(
+        self,
+        data: dict[str, str | WebClient],
+        description: EntityDescription,
+        entry: ConfigEntry,
+    ) -> None:
+        """Initialize a Slack entity."""
+        self._client = data[DATA_CLIENT]
+        self.entity_description = description
+        self._attr_unique_id = f"{data[ATTR_USER_ID]}_{description.key}"
+        self._attr_device_info = DeviceInfo(
+            configuration_url=data[ATTR_URL],
+            entry_type=DeviceEntryType.SERVICE,
+            identifiers={(DOMAIN, entry.entry_id)},
+            manufacturer=DEFAULT_NAME,
+            name=entry.title,
+        )
