@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from collections.abc import Callable
+from datetime import timedelta
 from typing import Any
 
 from pysnooz.api import UnknownSnoozState
@@ -12,16 +13,25 @@ from pysnooz.commands import (
     turn_off,
     turn_on,
 )
+import voluptuous as vol
 
 from homeassistant.components.fan import ATTR_PERCENTAGE, FanEntity, FanEntityFeature
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import STATE_OFF, STATE_ON
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
+from homeassistant.helpers import entity_platform
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.restore_state import RestoreEntity
 
-from .const import DOMAIN
+from .const import (
+    ATTR_DURATION,
+    ATTR_VOLUME,
+    DEFAULT_TRANSITION_DURATION,
+    DOMAIN,
+    SERVICE_TRANSITION_OFF,
+    SERVICE_TRANSITION_ON,
+)
 from .models import SnoozConfigurationData
 
 
@@ -30,6 +40,29 @@ async def async_setup_entry(
 ) -> None:
     """Set up Snooz device from a config entry."""
 
+    platform = entity_platform.async_get_current_platform()
+    platform.async_register_entity_service(
+        SERVICE_TRANSITION_ON,
+        {
+            vol.Optional(ATTR_VOLUME): vol.All(
+                vol.Coerce(int), vol.Range(min=0, max=100)
+            ),
+            vol.Optional(ATTR_DURATION, default=DEFAULT_TRANSITION_DURATION): vol.All(
+                vol.Coerce(int), vol.Range(min=1, max=300)
+            ),
+        },
+        "async_transition_on",
+    )
+    platform.async_register_entity_service(
+        SERVICE_TRANSITION_OFF,
+        {
+            vol.Optional(ATTR_DURATION, default=DEFAULT_TRANSITION_DURATION): vol.All(
+                vol.Coerce(int), vol.Range(min=1, max=300)
+            ),
+        },
+        "async_transition_off",
+    )
+
     data: SnoozConfigurationData = hass.data[DOMAIN][entry.entry_id]
 
     async_add_entities([SnoozFan(data)])
@@ -108,6 +141,18 @@ class SnoozFan(FanEntity, RestoreEntity):
             set_volume(percentage) if percentage > 0 else turn_off()
         )
 
+    async def async_transition_on(self, duration: int, **kwargs: Any) -> None:
+        """Transition on the device."""
+        await self._async_execute_command(
+            turn_on(volume=kwargs.get("volume"), duration=timedelta(seconds=duration))
+        )
+
+    async def async_transition_off(self, duration: int, **kwargs: Any) -> None:
+        """Transition off the device."""
+        await self._async_execute_command(
+            turn_off(duration=timedelta(seconds=duration))
+        )
+
     async def _async_execute_command(self, command: SnoozCommandData) -> None:
         result = await self._device.async_execute_command(command)
 
