@@ -23,7 +23,7 @@ from homeassistant.components.media_player import DOMAIN as MP_DOMAIN
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
-from homeassistant.helpers import entity_registry as ent_reg
+from homeassistant.helpers import entity_registry as er
 from homeassistant.helpers.dispatcher import (
     async_dispatcher_connect,
     async_dispatcher_send,
@@ -77,7 +77,7 @@ SUBSCRIPTION_SERVICES = {
     "renderingControl",
     "zoneGroupTopology",
 }
-SUPPORTED_VANISH_REASONS = ("sleeping", "switch to bluetooth", "upgrade")
+SUPPORTED_VANISH_REASONS = ("powered off", "sleeping", "switch to bluetooth", "upgrade")
 UNUSED_DEVICE_KEYS = ["SPID", "TargetRoomName"]
 
 
@@ -359,7 +359,8 @@ class SonosSpeaker:
         if any(isinstance(result, Exception) for result in results):
             raise SonosSubscriptionsFailed
 
-        # Create a polling task in case subscriptions fail or callback events do not arrive
+        # Create a polling task in case subscriptions fail
+        # or callback events do not arrive
         if not self._poll_timer:
             self._poll_timer = async_track_time_interval(
                 self.hass,
@@ -590,13 +591,20 @@ class SonosSpeaker:
             self.async_write_entity_states()
             self.hass.async_create_task(self.async_subscribe())
 
-    async def async_check_activity(self, now: datetime.datetime) -> None:
+    @callback
+    def async_check_activity(self, now: datetime.datetime) -> None:
         """Validate availability of the speaker based on recent activity."""
         if not self.available:
             return
         if time.monotonic() - self._last_activity < AVAILABILITY_TIMEOUT:
             return
+        # Ensure the ping is canceled at shutdown
+        self.hass.async_create_background_task(
+            self._async_check_activity(), f"sonos {self.uid} {self.zone_name} ping"
+        )
 
+    async def _async_check_activity(self) -> None:
+        """Validate availability of the speaker based on recent activity."""
         try:
             await self.hass.async_add_executor_job(self.ping)
         except SonosUpdateError:
@@ -836,7 +844,7 @@ class SonosSpeaker:
                 # Skip updating existing single speakers in polling mode
                 return
 
-            entity_registry = ent_reg.async_get(self.hass)
+            entity_registry = er.async_get(self.hass)
             sonos_group = []
             sonos_group_entities = []
 
