@@ -31,12 +31,12 @@ from homeassistant.util.unit_system import (
 from . import get_device_info
 from .const import (
     API_GEN_2,
+    API_GEN_3,
     DOMAIN,
     ENTRY_COORDINATOR,
     ENTRY_VEHICLES,
     VEHICLE_API_GEN,
     VEHICLE_HAS_EV,
-    VEHICLE_HAS_SAFETY_SERVICE,
     VEHICLE_STATUS,
     VEHICLE_VIN,
 )
@@ -51,7 +51,7 @@ FUEL_CONSUMPTION_MILES_PER_GALLON = "mi/gal"
 L_PER_GAL = VolumeConverter.convert(1, UnitOfVolume.GALLONS, UnitOfVolume.LITERS)
 KM_PER_MI = DistanceConverter.convert(1, UnitOfLength.MILES, UnitOfLength.KILOMETERS)
 
-# Sensor available to "Subaru Safety Plus" subscribers with Gen1 or Gen2 vehicles
+# Sensor available for Gen1 or Gen2 vehicles
 SAFETY_SENSORS = [
     SensorEntityDescription(
         key=sc.ODOMETER,
@@ -63,7 +63,7 @@ SAFETY_SENSORS = [
     ),
 ]
 
-# Sensors available to "Subaru Safety Plus" subscribers with Gen2 vehicles
+# Sensors available to subscribers with Gen2/Gen3 vehicles
 API_GEN_2_SENSORS = [
     SensorEntityDescription(
         key=sc.AVG_FUEL_CONSUMPTION,
@@ -110,7 +110,18 @@ API_GEN_2_SENSORS = [
     ),
 ]
 
-# Sensors available to "Subaru Safety Plus" subscribers with PHEV vehicles
+# Sensors available for Gen3 vehicles
+API_GEN_3_SENSORS = [
+    SensorEntityDescription(
+        key=sc.REMAINING_FUEL_PERCENT,
+        icon="mdi:gas-station",
+        name="Fuel level",
+        native_unit_of_measurement=PERCENTAGE,
+        state_class=SensorStateClass.MEASUREMENT,
+    ),
+]
+
+# Sensors available to subscribers with PHEV vehicles
 EV_SENSORS = [
     SensorEntityDescription(
         key=sc.EV_DISTANCE_TO_EMPTY,
@@ -156,14 +167,16 @@ def create_vehicle_sensors(
 ) -> list[SubaruSensor]:
     """Instantiate all available sensors for the vehicle."""
     sensor_descriptions_to_add = []
-    if vehicle_info[VEHICLE_HAS_SAFETY_SERVICE]:
-        sensor_descriptions_to_add.extend(SAFETY_SENSORS)
+    sensor_descriptions_to_add.extend(SAFETY_SENSORS)
 
-        if vehicle_info[VEHICLE_API_GEN] == API_GEN_2:
-            sensor_descriptions_to_add.extend(API_GEN_2_SENSORS)
+    if vehicle_info[VEHICLE_API_GEN] in [API_GEN_2, API_GEN_3]:
+        sensor_descriptions_to_add.extend(API_GEN_2_SENSORS)
 
-        if vehicle_info[VEHICLE_HAS_EV]:
-            sensor_descriptions_to_add.extend(EV_SENSORS)
+    if vehicle_info[VEHICLE_API_GEN] == API_GEN_3:
+        sensor_descriptions_to_add.extend(API_GEN_3_SENSORS)
+
+    if vehicle_info[VEHICLE_HAS_EV]:
+        sensor_descriptions_to_add.extend(EV_SENSORS)
 
     return [
         SubaruSensor(
@@ -268,7 +281,8 @@ async def _async_migrate_entries(
     all_sensors.extend(API_GEN_2_SENSORS)
     all_sensors.extend(SAFETY_SENSORS)
 
-    # Old unique_id is (previously title-cased) sensor name (e.g. "VIN_Avg Fuel Consumption")
+    # Old unique_id is (previously title-cased) sensor name
+    # (e.g. "VIN_Avg Fuel Consumption")
     replacements = {str(s.name).upper(): s.key for s in all_sensors}
 
     @callback
