@@ -7,8 +7,8 @@ from homeassistant.components.binary_sensor import (
     BinarySensorEntityDescription,
 )
 from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import EntityCategory
 from homeassistant.core import HomeAssistant
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN
@@ -20,30 +20,52 @@ PARALLEL_UPDATES = 0
 BINARY_SENSOR_TYPES: dict[str, BinarySensorEntityDescription] = {
     "calibration": BinarySensorEntityDescription(
         key="calibration",
-        name="Calibration",
+        translation_key="calibration",
         entity_category=EntityCategory.DIAGNOSTIC,
     ),
     "motion_detected": BinarySensorEntityDescription(
         key="pir_state",
-        name="Motion detected",
+        translation_key="motion",
         device_class=BinarySensorDeviceClass.MOTION,
     ),
     "contact_open": BinarySensorEntityDescription(
         key="contact_open",
-        name="Door open",
+        translation_key="door_open",
         device_class=BinarySensorDeviceClass.DOOR,
     ),
     "contact_timeout": BinarySensorEntityDescription(
         key="contact_timeout",
-        name="Door timeout",
+        translation_key="door_timeout",
         device_class=BinarySensorDeviceClass.PROBLEM,
         entity_category=EntityCategory.DIAGNOSTIC,
     ),
     "is_light": BinarySensorEntityDescription(
         key="is_light",
-        name="Light",
+        translation_key="light",
         device_class=BinarySensorDeviceClass.LIGHT,
     ),
+    "door_open": BinarySensorEntityDescription(
+        key="door_status",
+        translation_key="door_open",
+        device_class=BinarySensorDeviceClass.DOOR,
+    ),
+    "unclosed_alarm": BinarySensorEntityDescription(
+        key="unclosed_alarm",
+        translation_key="door_unclosed_alarm",
+        entity_category=EntityCategory.DIAGNOSTIC,
+        device_class=BinarySensorDeviceClass.PROBLEM,
+    ),
+    "unlocked_alarm": BinarySensorEntityDescription(
+        key="unlocked_alarm",
+        translation_key="door_unclosed_alarm",
+        entity_category=EntityCategory.DIAGNOSTIC,
+        device_class=BinarySensorDeviceClass.PROBLEM,
+    ),
+    "auto_lock_paused": BinarySensorEntityDescription(
+        key="auto_lock_paused",
+        translation_key="door_auto_lock_paused",
+        entity_category=EntityCategory.DIAGNOSTIC,
+    ),
 }
 
 
@@ -54,7 +76,7 @@ async def async_setup_entry(
     coordinator: SwitchbotDataUpdateCoordinator = hass.data[DOMAIN][entry.entry_id]
     async_add_entities(
         SwitchBotBinarySensor(coordinator, binary_sensor)
-        for binary_sensor in coordinator.data["data"]
+        for binary_sensor in coordinator.device.parsed_data
         if binary_sensor in BINARY_SENSOR_TYPES
     )
 
@@ -77,4 +99,4 @@ class SwitchBotBinarySensor(SwitchbotEntity, BinarySensorEntity):
     @property
     def is_on(self) -> bool:
         """Return the state of the sensor."""
-        return self.data["data"][self._sensor]
+        return self.parsed_data[self._sensor]
