@@ -84,12 +84,10 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     # For SSDP compat
     if not entry.data.get(CONF_MAC):
-        network = await hass.async_add_executor_job(getattr, api.dsm, "network")
         hass.config_entries.async_update_entry(
-            entry, data={**entry.data, CONF_MAC: network.macs}
+            entry, data={**entry.data, CONF_MAC: api.dsm.network.macs}
         )
 
-    # These all create executor jobs so we do not gather here
     coordinator_central = SynologyDSMCentralUpdateCoordinator(hass, entry, api)
     await coordinator_central.async_config_entry_first_refresh()
 
