@@ -4,7 +4,7 @@ from __future__ import annotations
 from collections.abc import Callable, Coroutine
 from dataclasses import dataclass
 import logging
-from typing import TYPE_CHECKING, Any, Generic
+from typing import TYPE_CHECKING, Any, Generic, TypeVar
 
 import aiounifi
 from aiounifi.interfaces.api_handlers import ItemEvent
@@ -19,24 +19,23 @@ from homeassistant.components.update import (
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant, callback
-from homeassistant.helpers.device_registry import CONNECTION_NETWORK_MAC
-from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from .const import ATTR_MANUFACTURER, DOMAIN as UNIFI_DOMAIN
-from .entity import DataT, HandlerT, UnifiEntity, UnifiEntityDescription
+from .const import DOMAIN as UNIFI_DOMAIN
+from .entity import (
+    UnifiEntity,
+    UnifiEntityDescription,
+    async_device_available_fn,
+    async_device_device_info_fn,
+)
 
 if TYPE_CHECKING:
     from .controller import UniFiController
 
 LOGGER = logging.getLogger(__name__)
 
-
-@callback
-def async_device_available_fn(controller: UniFiController, obj_id: str) -> bool:
-    """Check if device is available."""
-    device = controller.api.devices[obj_id]
-    return controller.available and not device.disabled
+_DataT = TypeVar("_DataT", bound=Device)
+_HandlerT = TypeVar("_HandlerT", bound=Devices)
 
 
 async def async_device_control_fn(api: aiounifi.Controller, obj_id: str) -> None:
@@ -44,33 +43,19 @@ async def async_device_control_fn(api: aiounifi.Controller, obj_id: str) -> None
     await api.request(DeviceUpgradeRequest.create(obj_id))
 
 
-@callback
-def async_device_device_info_fn(api: aiounifi.Controller, obj_id: str) -> DeviceInfo:
-    """Create device registry entry for device."""
-    device = api.devices[obj_id]
-    return DeviceInfo(
-        connections={(CONNECTION_NETWORK_MAC, device.mac)},
-        manufacturer=ATTR_MANUFACTURER,
-        model=device.model,
-        name=device.name or None,
-        sw_version=device.version,
-        hw_version=str(device.board_revision),
-    )
-
-
 @dataclass
-class UnifiEntityLoader(Generic[HandlerT, DataT]):
+class UnifiUpdateEntityDescriptionMixin(Generic[_HandlerT, _DataT]):
     """Validate and load entities from different UniFi handlers."""
 
     control_fn: Callable[[aiounifi.Controller, str], Coroutine[Any, Any, None]]
-    state_fn: Callable[[aiounifi.Controller, DataT], bool]
+    state_fn: Callable[[aiounifi.Controller, _DataT], bool]
 
 
 @dataclass
 class UnifiUpdateEntityDescription(
     UpdateEntityDescription,
-    UnifiEntityDescription[HandlerT, DataT],
-    UnifiEntityLoader[HandlerT, DataT],
+    UnifiEntityDescription[_HandlerT, _DataT],
+    UnifiUpdateEntityDescriptionMixin[_HandlerT, _DataT],
 ):
     """Class describing UniFi update entity."""
 
@@ -103,41 +88,15 @@ async def async_setup_entry(
 ) -> None:
     """Set up update entities for UniFi Network integration."""
     controller: UniFiController = hass.data[UNIFI_DOMAIN][config_entry.entry_id]
-
-    @callback
-    def async_load_entities(description: UnifiUpdateEntityDescription) -> None:
-        """Load and subscribe to UniFi devices."""
-        entities: list[UpdateEntity] = []
-        api_handler = description.api_handler_fn(controller.api)
-
-        @callback
-        def async_create_entity(event: ItemEvent, obj_id: str) -> None:
-            """Create UniFi entity."""
-            if not description.allowed_fn(
-                controller, obj_id
-            ) or not description.supported_fn(controller.api, obj_id):
-                return
-
-            entity = UnifiDeviceUpdateEntity(obj_id, controller, description)
-            if event == ItemEvent.ADDED:
-                async_add_entities([entity])
-                return
-            entities.append(entity)
-
-        for obj_id in api_handler:
-            async_create_entity(ItemEvent.CHANGED, obj_id)
-        async_add_entities(entities)
-
-        api_handler.subscribe(async_create_entity, ItemEvent.ADDED)
-
-    for description in ENTITY_DESCRIPTIONS:
-        async_load_entities(description)
+    controller.register_platform_add_entities(
+        UnifiDeviceUpdateEntity, ENTITY_DESCRIPTIONS, async_add_entities
+    )
 
 
-class UnifiDeviceUpdateEntity(UnifiEntity[HandlerT, DataT], UpdateEntity):
+class UnifiDeviceUpdateEntity(UnifiEntity[_HandlerT, _DataT], UpdateEntity):
     """Representation of a UniFi device update entity."""
 
-    entity_description: UnifiUpdateEntityDescription[HandlerT, DataT]
+    entity_description: UnifiUpdateEntityDescription[_HandlerT, _DataT]
 
     @callback
     def async_initiate_state(self) -> None:
@@ -163,12 +122,6 @@ class UnifiDeviceUpdateEntity(UnifiEntity[HandlerT, DataT], UpdateEntity):
         description = self.entity_description
 
         obj = description.object_fn(self.controller.api, self._obj_id)
-        if (
-            in_progress := description.state_fn(self.controller.api, obj)
-        ) != self.in_progress:
-            self._attr_in_progress = in_progress
-            self._write_state = True
+        self._attr_in_progress = description.state_fn(self.controller.api, obj)
         self._attr_installed_version = obj.version
         self._attr_latest_version = obj.upgrade_to_firmware or obj.version
-        if self.installed_version != self.latest_version:
-            self._write_state = True
