@@ -1,7 +1,7 @@
 """Const for Velbus."""
 from typing import Final
 
-from homeassistant.components.climate.const import (
+from homeassistant.components.climate import (
     PRESET_AWAY,
     PRESET_COMFORT,
     PRESET_ECO,
@@ -16,6 +16,7 @@ CONF_MEMO_TEXT: Final = "memo_text"
 SERVICE_SCAN: Final = "scan"
 SERVICE_SYNC: Final = "sync_clock"
 SERVICE_SET_MEMO_TEXT: Final = "set_memo_text"
+SERVICE_CLEAR_CACHE: Final = "clear_cache"
 
 PRESET_MODES: Final = {
     PRESET_ECO: "safe",
