@@ -4,28 +4,21 @@ import logging
 
 from aiohttp.client_exceptions import ClientResponseError
 import async_timeout
-import voluptuous as vol
 from volvooncall import Connection
 from volvooncall.dashboard import Instrument
 
-from homeassistant.config_entries import SOURCE_IMPORT, ConfigEntry
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
-    CONF_NAME,
     CONF_PASSWORD,
     CONF_REGION,
-    CONF_RESOURCES,
-    CONF_SCAN_INTERVAL,
     CONF_UNIT_SYSTEM,
     CONF_USERNAME,
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.exceptions import ConfigEntryAuthFailed
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
-import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_send
 from homeassistant.helpers.entity import DeviceInfo
-from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
-from homeassistant.helpers.typing import ConfigType
 from homeassistant.helpers.update_coordinator import (
     CoordinatorEntity,
     DataUpdateCoordinator,
@@ -35,11 +28,9 @@ from homeassistant.helpers.update_coordinator import (
 from .const import (
     CONF_MUTABLE,
     CONF_SCANDINAVIAN_MILES,
-    CONF_SERVICE_URL,
     DEFAULT_UPDATE_INTERVAL,
     DOMAIN,
     PLATFORMS,
-    RESOURCES,
     UNIT_SYSTEM_IMPERIAL,
     UNIT_SYSTEM_METRIC,
     UNIT_SYSTEM_SCANDINAVIAN_MILES,
@@ -49,68 +40,6 @@ from .errors import InvalidAuth
 
 _LOGGER = logging.getLogger(__name__)
 
-CONFIG_SCHEMA = vol.Schema(
-    vol.All(
-        cv.deprecated(DOMAIN),
-        {
-            DOMAIN: vol.Schema(
-                {
-                    vol.Required(CONF_USERNAME): cv.string,
-                    vol.Required(CONF_PASSWORD): cv.string,
-                    vol.Optional(
-                        CONF_SCAN_INTERVAL, default=DEFAULT_UPDATE_INTERVAL
-                    ): vol.All(cv.time_period, vol.Clamp(min=DEFAULT_UPDATE_INTERVAL)),
-                    vol.Optional(CONF_NAME, default={}): cv.schema_with_slug_keys(
-                        cv.string
-                    ),
-                    vol.Optional(CONF_RESOURCES): vol.All(
-                        cv.ensure_list, [vol.In(RESOURCES)]
-                    ),
-                    vol.Optional(CONF_REGION): cv.string,
-                    vol.Optional(CONF_SERVICE_URL): cv.string,
-                    vol.Optional(CONF_MUTABLE, default=True): cv.boolean,
-                    vol.Optional(CONF_SCANDINAVIAN_MILES, default=False): cv.boolean,
-                }
-            )
-        },
-    ),
-    extra=vol.ALLOW_EXTRA,
-)
-
-
-async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
-    """Migrate from YAML to ConfigEntry."""
-    if DOMAIN not in config:
-        return True
-
-    hass.data[DOMAIN] = {}
-
-    if not hass.config_entries.async_entries(DOMAIN):
-        new_conf = {}
-        new_conf[CONF_USERNAME] = config[DOMAIN][CONF_USERNAME]
-        new_conf[CONF_PASSWORD] = config[DOMAIN][CONF_PASSWORD]
-        new_conf[CONF_REGION] = config[DOMAIN].get(CONF_REGION)
-        new_conf[CONF_SCANDINAVIAN_MILES] = config[DOMAIN][CONF_SCANDINAVIAN_MILES]
-        new_conf[CONF_MUTABLE] = config[DOMAIN][CONF_MUTABLE]
-
-        hass.async_create_task(
-            hass.config_entries.flow.async_init(
-                DOMAIN, context={"source": SOURCE_IMPORT}, data=new_conf
-            )
-        )
-
-        async_create_issue(
-            hass,
-            DOMAIN,
-            "deprecated_yaml",
-            breaks_in_ha_version=None,
-            is_fixable=False,
-            severity=IssueSeverity.WARNING,
-            translation_key="deprecated_yaml",
-        )
-
-    return True
-
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up the Volvo On Call component from a ConfigEntry."""
