@@ -399,9 +399,9 @@ async def handle_manifest_get(
         connection.send_error(msg["id"], const.ERR_NOT_FOUND, "Integration not found")
 
 
+@callback
 @decorators.websocket_command({vol.Required("type"): "integration/setup_info"})
-@decorators.async_response
-async def handle_integration_setup_info(
+def handle_integration_setup_info(
     hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
 ) -> None:
     """Handle integrations command."""
@@ -648,6 +648,7 @@ async def handle_execute_script(
     connection.send_result(msg["id"], {"context": context})
 
 
+@callback
 @decorators.websocket_command(
     {
         vol.Required("type"): "fire_event",
@@ -656,8 +657,7 @@ async def handle_execute_script(
     }
 )
 @decorators.require_admin
-@decorators.async_response
-async def handle_fire_event(
+def handle_fire_event(
     hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
 ) -> None:
     """Handle fire event command."""
