@@ -1,18 +1,29 @@
 """Helpers for WLED."""
+from __future__ import annotations
+
+from collections.abc import Callable, Coroutine
+from typing import Any, Concatenate, ParamSpec, TypeVar
 
 from wled import WLEDConnectionError, WLEDError
 
 from homeassistant.exceptions import HomeAssistantError
 
+from .models import WLEDEntity
 
-def wled_exception_handler(func):
+_WLEDEntityT = TypeVar("_WLEDEntityT", bound=WLEDEntity)
+_P = ParamSpec("_P")
+
+
+def wled_exception_handler(
+    func: Callable[Concatenate[_WLEDEntityT, _P], Coroutine[Any, Any, Any]]
+) -> Callable[Concatenate[_WLEDEntityT, _P], Coroutine[Any, Any, None]]:
     """Decorate WLED calls to handle WLED exceptions.
 
     A decorator that wraps the passed in function, catches WLED errors,
     and handles the availability of the device in the data coordinator.
     """
 
-    async def handler(self, *args, **kwargs):
+    async def handler(self: _WLEDEntityT, *args: _P.args, **kwargs: _P.kwargs) -> None:
         try:
             await func(self, *args, **kwargs)
             self.coordinator.async_update_listeners()
