@@ -184,3 +184,15 @@ class AqaraPetFeederFeedButton(ZHAAttributeButton, id_suffix="feeding"):
     _attribute_name = "feeding"
     _attr_name = "Feed"
     _attribute_value = 1
+
+
+@CONFIG_DIAGNOSTIC_MATCH(
+    channel_names="opple_cluster", models={"lumi.sensor_smoke.acn03"}
+)
+class AqaraSelfTestButton(ZHAAttributeButton, id_suffix="self_test"):
+    """Defines a ZHA self-test button for Aqara smoke sensors."""
+
+    _attribute_name = "self_test"
+    _attr_name = "Self-test"
+    _attribute_value = 1
+    _attr_entity_category = EntityCategory.CONFIG
