@@ -2,12 +2,12 @@
 from __future__ import annotations
 
 from collections.abc import Callable
-from typing import Any, TypeVar, Union
+from typing import Any, TypeVar
 
 _TypeT = TypeVar("_TypeT", bound=type[Any])
 
 
-class DictRegistry(dict[Union[int, str], _TypeT]):
+class DictRegistry(dict[int | str, _TypeT]):
     """Dict Registry of items."""
 
     def register(self, name: int | str) -> Callable[[_TypeT], _TypeT]:
@@ -21,7 +21,7 @@ class DictRegistry(dict[Union[int, str], _TypeT]):
         return decorator
 
 
-class SetRegistry(set[Union[int, str]]):
+class SetRegistry(set[int | str]):
     """Set Registry of items."""
 
     def register(self, name: int | str) -> Callable[[_TypeT], _TypeT]:
