@@ -12,6 +12,7 @@ from __future__ import annotations
 from collections import UserDict
 from collections.abc import Callable, Iterable, Mapping, ValuesView
 import logging
+from types import MappingProxyType
 from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 import attr
@@ -111,6 +112,29 @@ DISLAY_DICT_OPTIONAL = (
 )
 
 
+class _EntityOptions(UserDict[str, MappingProxyType]):
+    """Container for entity options."""
+
+    def __init__(self, data: Mapping[str, Mapping] | None) -> None:
+        """Initialize."""
+        super().__init__()
+        if data is None:
+            return
+        self.data = {key: MappingProxyType(val) for key, val in data.items()}
+
+    def __setitem__(self, key: str, entry: Mapping) -> None:
+        """Add an item."""
+        raise NotImplementedError
+
+    def __delitem__(self, key: str) -> None:
+        """Remove an item."""
+        raise NotImplementedError
+
+    def as_dict(self) -> dict[str, dict]:
+        """Return dictionary version."""
+        return {key: dict(val) for key, val in self.data.items()}
+
+
 @attr.s(slots=True, frozen=True)
 class RegistryEntry:
     """Entity Registry Entry."""
@@ -132,10 +156,7 @@ class RegistryEntry:
     id: str = attr.ib(factory=uuid_util.random_uuid_hex)
     has_entity_name: bool = attr.ib(default=False)
     name: str | None = attr.ib(default=None)
-    options: EntityOptionsType = attr.ib(
-        default=None,
-        converter=attr.converters.default_if_none(factory=dict),  # type: ignore[misc]
-    )
+    options: _EntityOptions = attr.ib(default=None, converter=_EntityOptions)
     # As set by integration
     original_device_class: str | None = attr.ib(default=None)
     original_icon: str | None = attr.ib(default=None)
@@ -930,7 +951,7 @@ class EntityRegistry:
         If the domain options are set to None, they will be removed.
         """
         old = self.entities[entity_id]
-        new_options = {
+        new_options: dict[str, Mapping] = {
             key: value for key, value in old.options.items() if key != domain
         }
         if options is not None:
@@ -1010,7 +1031,7 @@ class EntityRegistry:
                 "id": entry.id,
                 "has_entity_name": entry.has_entity_name,
                 "name": entry.name,
-                "options": entry.options,
+                "options": entry.options.as_dict(),
                 "original_device_class": entry.original_device_class,
                 "original_icon": entry.original_icon,
                 "original_name": entry.original_name,
