@@ -176,7 +176,7 @@ def async_track_state_change(
     else:
         entity_ids = tuple(entity_id.lower() for entity_id in entity_ids)
 
-    job = HassJob(action)
+    job = HassJob(action, f"track state change {entity_ids} {from_state} {to_state}")
 
     @callback
     def state_change_filter(event: Event) -> bool:
@@ -296,7 +296,7 @@ def _async_track_state_change_event(
             event_filter=_async_state_change_filter,
         )
 
-    job = HassJob(action)
+    job = HassJob(action, f"track state change event {entity_ids}")
 
     for entity_id in entity_ids:
         entity_callbacks.setdefault(entity_id, []).append(job)
@@ -393,7 +393,7 @@ def async_track_entity_registry_updated_event(
             event_filter=_async_entity_registry_updated_filter,
         )
 
-    job = HassJob(action)
+    job = HassJob(action, f"track entity registry updated event {entity_ids}")
 
     for entity_id in entity_ids:
         entity_callbacks.setdefault(entity_id, []).append(job)
@@ -412,18 +412,21 @@ def async_track_entity_registry_updated_event(
     return remove_listener
 
 
+@callback
+def _async_domain_has_listeners(
+    domain: str, callbacks: dict[str, list[HassJob[[Event], Any]]]
+) -> bool:
+    """Check if the domain has any listeners."""
+    return domain in callbacks or MATCH_ALL in callbacks
+
+
 @callback
 def _async_dispatch_domain_event(
     hass: HomeAssistant, event: Event, callbacks: dict[str, list[HassJob[[Event], Any]]]
 ) -> None:
+    """Dispatch domain event listeners."""
     domain = split_entity_id(event.data["entity_id"])[0]
-
-    if domain not in callbacks and MATCH_ALL not in callbacks:
-        return
-
-    listeners = callbacks.get(domain, []) + callbacks.get(MATCH_ALL, [])
-
-    for job in listeners:
+    for job in callbacks.get(domain, []) + callbacks.get(MATCH_ALL, []):
         try:
             hass.async_run_hass_job(job, event)
         except Exception:  # pylint: disable=broad-except
@@ -460,14 +463,13 @@ def _async_track_state_added_domain(
         @callback
         def _async_state_change_filter(event: Event) -> bool:
             """Filter state changes by entity_id."""
-            return event.data.get("old_state") is None
+            return event.data.get("old_state") is None and _async_domain_has_listeners(
+                split_entity_id(event.data["entity_id"])[0], domain_callbacks
+            )
 
         @callback
         def _async_state_change_dispatcher(event: Event) -> None:
             """Dispatch state changes by entity_id."""
-            if event.data.get("old_state") is not None:
-                return
-
             _async_dispatch_domain_event(hass, event, domain_callbacks)
 
         hass.data[TRACK_STATE_ADDED_DOMAIN_LISTENER] = hass.bus.async_listen(
@@ -476,7 +478,7 @@ def _async_track_state_added_domain(
             event_filter=_async_state_change_filter,
         )
 
-    job = HassJob(action)
+    job = HassJob(action, f"track state added domain event {domains}")
 
     for domain in domains:
         domain_callbacks.setdefault(domain, []).append(job)
@@ -514,14 +516,13 @@ def async_track_state_removed_domain(
         @callback
         def _async_state_change_filter(event: Event) -> bool:
             """Filter state changes by entity_id."""
-            return event.data.get("new_state") is None
+            return event.data.get("new_state") is None and _async_domain_has_listeners(
+                split_entity_id(event.data["entity_id"])[0], domain_callbacks
+            )
 
         @callback
         def _async_state_change_dispatcher(event: Event) -> None:
             """Dispatch state changes by entity_id."""
-            if event.data.get("new_state") is not None:
-                return
-
             _async_dispatch_domain_event(hass, event, domain_callbacks)
 
         hass.data[TRACK_STATE_REMOVED_DOMAIN_LISTENER] = hass.bus.async_listen(
@@ -530,7 +531,7 @@ def async_track_state_removed_domain(
             event_filter=_async_state_change_filter,
         )
 
-    job = HassJob(action)
+    job = HassJob(action, f"track state removed domain event {domains}")
 
     for domain in domains:
         domain_callbacks.setdefault(domain, []).append(job)
@@ -569,7 +570,9 @@ class _TrackStateChangeFiltered:
         """Handle removal / refresh of tracker init."""
         self.hass = hass
         self._action = action
-        self._action_as_hassjob = HassJob(action)
+        self._action_as_hassjob = HassJob(
+            action, f"track state change filtered {track_states}"
+        )
         self._listeners: dict[str, Callable[[], None]] = {}
         self._last_track_states: TrackStates = track_states
 
@@ -764,7 +767,7 @@ def async_track_template(
     Callable to unregister the listener.
 
     """
-    job = HassJob(action)
+    job = HassJob(action, f"track template {template}")
 
     @callback
     def _template_changed_listener(
@@ -821,7 +824,7 @@ class TrackTemplateResultInfo:
     ) -> None:
         """Handle removal / refresh of tracker init."""
         self.hass = hass
-        self._job = HassJob(action)
+        self._job = HassJob(action, f"track template result {track_templates}")
 
         for track_template_ in track_templates:
             track_template_.template.hass = hass
@@ -835,6 +838,10 @@ class TrackTemplateResultInfo:
         self._track_state_changes: _TrackStateChangeFiltered | None = None
         self._time_listeners: dict[Template, Callable[[], None]] = {}
 
+    def __repr__(self) -> str:
+        """Return the representation."""
+        return f"<TrackTemplateResultInfo {self._info}>"
+
     def async_setup(self, raise_on_template_error: bool, strict: bool = False) -> None:
         """Activation of template tracking."""
         block_render = False
@@ -1215,7 +1222,7 @@ def async_track_same_state(
     async_remove_state_for_cancel: CALLBACK_TYPE | None = None
     async_remove_state_for_listener: CALLBACK_TYPE | None = None
 
-    job = HassJob(action)
+    job = HassJob(action, f"track same state {period} {entity_ids}")
 
     @callback
     def clear_listener() -> None:
@@ -1277,7 +1284,11 @@ def async_track_point_in_time(
     point_in_time: datetime,
 ) -> CALLBACK_TYPE:
     """Add a listener that fires once after a specific point in time."""
-    job = action if isinstance(action, HassJob) else HassJob(action)
+    job = (
+        action
+        if isinstance(action, HassJob)
+        else HassJob(action, f"track point in time {point_in_time}")
+    )
 
     @callback
     def utc_converter(utc_now: datetime) -> None:
@@ -1324,7 +1335,11 @@ def async_track_point_in_utc_time(
 
         hass.async_run_hass_job(job, utc_point_in_time)
 
-    job = action if isinstance(action, HassJob) else HassJob(action)
+    job = (
+        action
+        if isinstance(action, HassJob)
+        else HassJob(action, f"track point in utc time {utc_point_in_time}")
+    )
     delta = expected_fire_timestamp - time.time()
     cancel_callback = hass.loop.call_later(delta, run_action, job)
 
@@ -1357,7 +1372,11 @@ def async_call_later(
         """Call the action."""
         hass.async_run_hass_job(job, time_tracker_utcnow())
 
-    job = action if isinstance(action, HassJob) else HassJob(action)
+    job = (
+        action
+        if isinstance(action, HassJob)
+        else HassJob(action, f"call_later {delay}")
+    )
     cancel_callback = hass.loop.call_later(delay, run_action, job)
 
     @callback
@@ -1378,12 +1397,14 @@ def async_track_time_interval(
     hass: HomeAssistant,
     action: Callable[[datetime], Coroutine[Any, Any, None] | None],
     interval: timedelta,
+    *,
+    name: str | None = None,
 ) -> CALLBACK_TYPE:
     """Add a listener that fires repetitively at every timedelta interval."""
     remove: CALLBACK_TYPE
     interval_listener_job: HassJob[[datetime], None]
 
-    job = HassJob(action)
+    job = HassJob(action, f"track time interval {interval}")
 
     def next_interval() -> datetime:
         """Return the next interval."""
@@ -1400,7 +1421,12 @@ def async_track_time_interval(
         )
         hass.async_run_hass_job(job, now)
 
-    interval_listener_job = HassJob(interval_listener)
+    if name:
+        job_name = f"{name}: track time interval {interval}"
+    else:
+        job_name = f"track time interval {interval}"
+
+    interval_listener_job = HassJob(interval_listener, job_name)
     remove = async_track_point_in_utc_time(hass, interval_listener_job, next_interval())
 
     def remove_listener() -> None:
@@ -1479,7 +1505,9 @@ def async_track_sunrise(
     hass: HomeAssistant, action: Callable[[], None], offset: timedelta | None = None
 ) -> CALLBACK_TYPE:
     """Add a listener that will fire a specified offset from sunrise daily."""
-    listener = SunListener(hass, HassJob(action), SUN_EVENT_SUNRISE, offset)
+    listener = SunListener(
+        hass, HassJob(action, "track sunrise"), SUN_EVENT_SUNRISE, offset
+    )
     listener.async_attach()
     return listener.async_detach
 
@@ -1493,7 +1521,9 @@ def async_track_sunset(
     hass: HomeAssistant, action: Callable[[], None], offset: timedelta | None = None
 ) -> CALLBACK_TYPE:
     """Add a listener that will fire a specified offset from sunset daily."""
-    listener = SunListener(hass, HassJob(action), SUN_EVENT_SUNSET, offset)
+    listener = SunListener(
+        hass, HassJob(action, "track sunset"), SUN_EVENT_SUNSET, offset
+    )
     listener.async_attach()
     return listener.async_detach
 
@@ -1526,7 +1556,7 @@ def async_track_utc_time_change(
         # misalignment we use async_track_time_interval here
         return async_track_time_interval(hass, action, timedelta(seconds=1))
 
-    job = HassJob(action)
+    job = HassJob(action, f"track time change {hour}:{minute}:{second} local={local}")
     matching_seconds = dt_util.parse_time_expression(second, 0, 59)
     matching_minutes = dt_util.parse_time_expression(minute, 0, 59)
     matching_hours = dt_util.parse_time_expression(hour, 0, 23)
@@ -1630,12 +1660,6 @@ def _render_infos_needs_all_listener(render_infos: Iterable[RenderInfo]) -> bool
         if render_info.all_states or render_info.all_states_lifecycle:
             return True
 
-        # Previous call had an exception
-        # so we do not know which states
-        # to track
-        if render_info.exception:
-            return True
-
     return False
 
 
